/*
 *
 *
AnimV: (tmdanim) Animation Viewer
Controls:

L1/L2: Toggle L1: static view (hold for camera to follow), L2: follow view
R1/R2: Toggle R1: map with lights and fog  R2: toggle debugging box (MinMax), spinning boxes

up: move model up (Z+)
down: move model down (Z-)
left: move model left (X-)
right: move model right (X+)

Triangle: view up (Y-)
Cross: view up (Y+)
Square: short view (Z-)
Circle: far view (Z+)

select: pause animation
select + up: speed animation
select + down: slow animation

start: reset model coordinate
start + select: exit (back to siocons)



Original code from: Peter Passmore 3D course - COM3311 Programming Interactive Graphical Systems
Middlesex University, 1997,
Copyright P.J. Passmore.
COM3311 Programming Interactive Graphical Systems
Net Yaroze Tutorial



compile:
mips-unknown-ecoff-gcc -g  -O3 -Werror -funsigned-char -c psx.c -o main.o
mips-unknown-ecoff-gcc -Xlinker -Map -Xlinker mapfile.txt -Xlinker -Ttext -Xlinker 8011d9ff  main.o -o main.exe


create siocons.auto file:
local load main.exe
go

run:
yarexe siocons.auto
no$psx psx.exe






 */


//#define DEBUG

//#define DEBUG


//FOG colour
#define FOG_RED   0x33
#define FOG_GREEN 0x22
#define FOG_BLUE  0x0A

#define FOG_DEPTH 5128 //the bigger it is, the closer the fog starts to the view point


/* Generated by bin2c, do not edit manually */

/* Contents of file COM.TIM */
const long int COM_TIM_size = 1088;
extern const unsigned char COM_TIM[1088];


const long int MODEL00_TMD_size = 248;
extern const unsigned char MODEL00_TMD[248];

const long int CAR01_TMD_size = 9120;
extern const unsigned char CAR01_TMD[9120];

const long int FLAT_TMD_size = 272;
extern const unsigned char FLAT_TMD[272];
/************************************************************
 *															*
 *						Pad.c								*
 *															*
 *															*
 *		Set of pad routines to present a similar interface 	*
 *		to the controller pad as dtlh2500					*
 *															*
 *	Copyright (C) 1996 Sony Computer Entertainment Inc.		*
 *	All Rights Reserved										*
 *															*
 ***********************************************************/




/***************************************
			Use:

		call PadInit();	as part of initialisation in main

		each frame (VSync loop),
		call PadRead(): puts pad status into an unsigned long variable

		e.g. padStatus = PadRead();

		then, test individual buttons by masking the pad status variable
		with the #defined constants in pad.h

		e.g. if (padStatus & PADLleft)	 // Pad L left button is pressed
				{
				// do actions here
				}


 ***************************************/



/************************************************************
 *															*
 *						Pad.h								*
 *															*
 *															*
 *	Copyright (C) 1996 Sony Computer Entertainment Inc.		*
 *	All Rights Reserved										*
 *															*
 ***********************************************************/

#include <stdio.h>
#include <stdlib.h>
#include <libps.h>
//#include <string.h>
// prototypes for pad.c
void PadInit (void);
u_long PadRead (void);


// best to use Hsync values, it's easier to understand 1/60 or 1/50
#define COUNTER   VSync(1)
//VSync(-1)
//GetRCnt(1)

#if 1

#ifdef __GNUC__

#if __GNUC__ < 3 // NY DJGPP & PSX3
// GetRCnt(1);\
// see GCC 2.7.2 macro help file:///C:/psx3/doc/gnuinfo/gcc_69.html#SEC71
// modern https://en.wikibooks.org/wiki/C_Programming/Preprocessor_directives_and_macros#cite_note-14
#define LOGF( _ARGS_...) \
if(1)\
{ \
long r1,r2, t1,  t2;\
t1 = COUNTER; \
r1 = GetRCnt(1);\
printf("LOG %s %s %d", #_ARGS_, __FILE__, __LINE__); \
_ARGS_;\
t2 = COUNTER;\
r2 = GetRCnt(1);\
printf(" %d %d\n", t1-t2, r1-r2); \
}

#endif //#if __GNUC__ < 3

#else //#ifdef __GNUC__
#ifdef  __MWERKS__
// CW - I can't figure out if or where ARGS macro is??? searched the docs - nothing
#define LOGF(X) X;
#endif //#ifdef  __MWERKS__

#endif //#ifdef __GNUC__


#else

#define LOGF( _ARGS_...) _ARGS_;



#endif


#include "data.h"

#define TMDANIM_IMPL
#include "tmdanim.h"





int (*LOG)(char *format, ...);


int g_box_on = 0;
int g_env_on = 0;
int g_pause_anim_on = 0;




u_long g_frame=0;
u_long g_time=0;



TMDANIMHDR *g_anim_walk;
TMDANIMHDR *g_anim_jump;

player_t g_character;

int DUMMY( char *format, ...)
{
	return (int) format;
}


// constants for interface
#define PADLup     (1<<12)
#define PADLdown   (1<<14)
#define PADLleft   (1<<15)
#define PADLright  (1<<13)
#define PADRup     (1<< 4)
#define PADRdown   (1<< 6)
#define PADRleft   (1<< 7)
#define PADRright  (1<< 5)
#define PADi       (1<< 9)
#define PADj       (1<<10)
#define PADk       (1<< 8)
#define PADl       (1<< 3)
#define PADm       (1<< 1)
#define PADn       (1<< 2)
#define PADo       (1<< 0)
#define PADh       (1<<11)
#define PADL1      PADn
#define PADL2      PADo
#define PADR1      PADl
#define PADR2      PADm
#define PADstart   PADh
#define PADselect  PADk

/**************************************
 THESE ADDITIONS BY SEAN BUTLER
 14 JULY 1997
 **************************************/

#define PADtriangle PADRup
#define PADcross    PADRdown
#define PADsquare   PADRleft
#define PADcircle   PADRright


// low-level pad buffers: never need to touch
volatile u_char *bb0, *bb1;





// call once only in program initialisation
void PadInit (void)
{
	GetPadBuf(&bb0, &bb1);
}





// call once per VSync(0)
// puts controller pad status into unsigned long integer

// please refer to the manuals if you want explanation
// of the internals of this function
u_long PadRead(void)
{
	return(~(*(bb0+3) | *(bb0+2) << 8 | *(bb1+3) << 16 | *(bb1+2) << 24));
}





/***************************************************************
	 main.c
	 ======

 ***************************************************************/


#define ORDERING_TABLE_LENGTH (12)
#define MAX_NO_PACKETS  (248000)
#define SCREEN_WIDTH  (320)
#define SCREEN_HEIGHT (240)
#define MAX_X (15)
#define MAX_Z (15)
#define MAX_WORLD_OBJECTS   (225)
#define SEPERATION (1200)

#define CAR_MEM_ADDR  (CAR01_TMD)
#define CAR_TEX_MEM_ADDR    (COM_TIM)
#define SQUARE1_MEM_ADDR     (FLAT_TMD)
// #define SQUARE1_TEX_MEM_ADDR   (0x800B0000)

// a variable to track the vsync interval
u_long vsyncInterval=0;

unsigned long PLAYING=1;

u_long PADstatus=0;
// We need two Ordering Table Headers, one for each buffer
GsOT othWorld[2];
// And we need Two Ordering Tables, one for each buffer
GsOT_TAG        otWorld[2][1<<ORDERING_TABLE_LENGTH];
//We also allocate memory used for depth sorting, a block for each buffer
PACKET          out_packet[2][MAX_NO_PACKETS];
// We need a viewing system for 3D graphics
GsRVIEW2        view;
// This is an array of structures for the lights
GsF_LIGHT       flLights[3];
// Define a structure to hold a 3D object that will be rendered on screen
typedef struct
{
	long speed;
	SVECTOR rotation;
	GsDOBJ2         gsObjectHandler;
	GsCOORDINATE2   gsObjectCoord;
}ObjStructType;
// Create and instance of the structure to hold our car object (tmd)
ObjStructType theModel, ball1, ball2, ball3;
TMD_FLAT_3D_RECT *g_debug_tmd_cube;
GsDOBJ2 g_debug_obj_cube={0};
GsCOORDINATE2 	g_debug_coord_cube={0};

// 4 point cube rendered only in current local display space, ie after another object has been transformed into screen space etc.
// useful for obj bounding space etc.
TMD_FLAT_3D_RECT *g_debug_tmd_cube_local;
GsDOBJ2 g_debug_obj_cube_local={0};
TMD_MIN_MAX *g_min_max;

typedef struct
{
	// A variable to track the total number of models in the world
	int nTotalModels;
	// We need one of each of the following two data structures for each
	// object in the world thus we have arrays of them
	GsDOBJ2         gsObjectHandler[MAX_WORLD_OBJECTS];
	GsCOORDINATE2   gsObjectCoord[MAX_WORLD_OBJECTS];
	// We also need an array of pointers to tmds in memory
	unsigned long *lObjectPointer[MAX_WORLD_OBJECTS];

} WorldStructType0;
WorldStructType0     theWorld;

char worldGroundData[MAX_Z][MAX_X] ={
		{'1','1','1','1','1','1','1','1','1','1','1','1','1','1','1'},
		{'1','1','0','0','0','0','0','0','0','0','0','0','0','0','1'},
		{'1','0','1','0','0','0','0','0','0','0','0','0','0','0','1'},
		{'1','0','0','1','0','0','0','0','0','0','0','0','0','0','1'},
		{'1','0','0','0','1','0','0','0','0','0','0','0','0','0','1'},
		{'1','0','0','0','0','1','0','0','0','0','0','0','0','0','1'},
		{'1','0','0','0','0','0','1','0','0','0','0','0','0','0','1'},
		{'1','0','0','0','0','0','0','1','0','0','0','0','0','0','1'},
		{'1','0','0','0','0','0','0','0','1','0','0','0','0','0','1'},
		{'1','0','0','0','0','0','0','0','0','0','0','0','0','0','1'},
		{'1','0','0','0','0','0','0','0','0','0','0','0','0','0','1'},
		{'1','0','0','0','0','0','0','0','0','0','0','0','0','0','1'},
		{'1','0','0','0','0','0','0','0','0','0','0','0','0','0','1'},
		{'1','0','0','0','0','0','0','0','0','0','0','0','0','0','1'},
		{'1','1','1','1','1','1','1','1','1','1','1','1','1','1','1'},
};

/************* FUNCTION PROTOTYPES *******************/
void AddModelToWorld(WorldStructType0 *theWorld, int nX, int nY, int nZ,
		unsigned long *lModelAddress);
int LoadTexture(long addr);
void InitialiseWorld ();
void DrawWorld(WorldStructType0 *theWorld, GsOT *othWorld);
void AddModelToObj(ObjStructType *obj, int nX, int nY, int nZ,
		unsigned long *lModelAddress);
void InitialiseObj(ObjStructType *obj, int nX, int nY, int nZ,
		unsigned long *lModelAddress);
void DrawObj(ObjStructType *obj, GsOT *othWorld);
void RenderWorld(ObjStructType *obj,ObjStructType *ball1,ObjStructType *ball2,ObjStructType *ball3, WorldStructType0 *theWorld);
void InitialiseLight(GsF_LIGHT *flLight, int nLight, int nX, int nY, int nZ,
		int nRed, int nGreen, int nBlue);
void InitialiseTrackerView(GsRVIEW2 *view, int nProjDist, int nRZ,
		int nVPX, int nVPY, int nVPZ,
		int nVRX, int nVRY, int nVRZ);
void InitialiseStaticView(GsRVIEW2 *view, int nProjDist, int nRZ,
		int nVPX, int nVPY, int nVPZ,
		int nVRX, int nVRY, int nVRZ);
void ResetMatrix(short m[3][3]);
void RotateModel (GsCOORDINATE2 *gsObjectCoord,SVECTOR *rotateVector , int nRX,
		int nRY, int nRZ );
void AdvanceModel (GsCOORDINATE2 *gsObjectCoord, SVECTOR *rotateVector,
		long *speed, int nD);
void ProcessUserInput();


void debug_print_cube(TMD_FLAT_3D_RECT *cube)
{

	int i;


	printf("\n\n cube add: 0x%x\n\n\n", cube);

	printf("cube cube->tmd_hdr.id %d 0x%x \n", cube->tmd_hdr.id, cube->tmd_hdr.id);
	printf("cube cube->tmd_hdr.flag %d 0x%x \n", cube->tmd_hdr.flag, cube->tmd_hdr.flag);
	printf("cube cube->tmd_hdr.nobjs %d 0x%x \n\n", cube->tmd_hdr.nobj, cube->tmd_hdr.nobj);


	printf("cube cube->obj_table.n_primitive  %d 0x%x \n", cube->obj_table.n_primitive , cube->obj_table.n_primitive);
	printf("cube cube->obj_table.primitive_top  %d 0x%x \n", cube->obj_table.primitive_top , cube->obj_table.primitive_top);
	printf("cube cube->obj_table.n_vert %d 0x%x \n", cube->obj_table.n_vert , cube->obj_table.n_vert);
	printf("cube cube->obj_table.vert_top %d 0x%x \n", cube->obj_table.vert_top , cube->obj_table.vert_top);
	printf("cube cube->obj_table.n_normal %d 0x%x \n", cube->obj_table.n_normal , cube->obj_table.n_normal);
	printf("cube cube->obj_table.normal_top %d 0x%x \n", cube->obj_table.normal_top , cube->obj_table.normal_top);
	printf("cube cube->obj_table.scale %d 0x%x \n\n", cube->obj_table.scale , cube->obj_table.scale);


	for(i=0; i<cube->obj_table.n_primitive; i++)
	{
		printf(" \n------------------ PRIM DATA %d/%d\n\n\n\n", i, cube->obj_table.n_primitive);
		printf("cube cube->prim_data[i].hdr.flag  %d 0x%x \n", cube->prim_data[i].hdr.flag ,cube->prim_data[i].hdr.flag );
		printf("cube cube->prim_data[i].hdr.mode  %d 0x%x \n", cube->prim_data[i].hdr.mode ,cube->prim_data[i].hdr.mode );
		printf("cube cube->prim_data[i].hdr.ilen  %d 0x%x \n", cube->prim_data[i].hdr.ilen ,cube->prim_data[i].hdr.ilen );
		printf("cube cube->prim_data[i].hdr.olen  %d 0x%x \n", cube->prim_data[i].hdr.olen ,cube->prim_data[i].hdr.olen );

		printf("cube cube->prim_data RGB  %d %d %d \n", cube->prim_data[i].data.r0 , cube->prim_data[i].data.g0,  cube->prim_data[i].data.b0);
		printf("cube cube->prim_data VERT  %d %d %d %d \n", cube->prim_data[i].data.vert0 , cube->prim_data[i].data.vert1 ,cube->prim_data[i].data.vert2 ,cube->prim_data[i].data.vert3);

		printf("cube cube->prim_data mode2  %d \n", cube->prim_data[i].data.mode2);


	}


	printf(" \n------------------ VERT DATA %d\n\n\n\n",  cube->obj_table.n_vert);
	for(i=0; i<cube->obj_table.n_vert; i++)
	{

		printf("cube cube->vert_data[ %d ]  %d  %d  %d \n", i, cube->vert_data[i].vx, cube->vert_data[i].vy, cube->vert_data[i].vz);


	}






}


/*****************************************************/
void AddModelToWorld(WorldStructType0 *theWorld, int nX, int nY, int nZ,
		unsigned long *lModelAddress)
{
	theWorld->lObjectPointer[theWorld->nTotalModels] = (unsigned long*)lModelAddress;
	//increment the pointer to move past the model id. (weird huh?)
	theWorld->lObjectPointer[theWorld->nTotalModels]++;
	// map tmd data to its actual address
	GsMapModelingData(theWorld->lObjectPointer[theWorld->nTotalModels]);
	// initialise the objects coordinate system - set to be that of the WORLD
	GsInitCoordinate2(WORLD, &theWorld->gsObjectCoord[theWorld->nTotalModels]);
	// increment pointer twice more - to point to top of model data (beats me!)
	theWorld->lObjectPointer[theWorld->nTotalModels]++;
	theWorld->lObjectPointer[theWorld->nTotalModels]++;
	// link the model (tmd) with the players object handler
	GsLinkObject4((unsigned long )theWorld->lObjectPointer[theWorld->nTotalModels],
			&theWorld->gsObjectHandler[theWorld->nTotalModels], 0);
	// set the amount of polygon subdivision that will be done at runtime (none!)
	theWorld->gsObjectHandler[theWorld->nTotalModels].attribute = GsDIV1;
	// Assign the coordinates of the object model to the Object Handler
	theWorld->gsObjectHandler[theWorld->nTotalModels].coord2 =
			&theWorld->gsObjectCoord[theWorld->nTotalModels];
	// Set The Position of the Object
	theWorld->gsObjectCoord[theWorld->nTotalModels].coord.t[0]=nX;   // X
	theWorld->gsObjectCoord[theWorld->nTotalModels].coord.t[1]=nY;   // Y
	theWorld->gsObjectCoord[theWorld->nTotalModels].coord.t[2]=nZ;   // Z
	// Increment the object counter
	theWorld->nTotalModels++;
	// flag the object as needing to be drawn
	theWorld->gsObjectCoord[theWorld->nTotalModels].flg = 0;
}

// load up from conventional memeory into video memory
int LoadTexture(long addr)
{
	RECT rect;
	GsIMAGE tim1;

	// get tim info/header, again a little bit of majic is needd the pointer
	// is incremented past the first 4 positions to get to this!
	GsGetTimInfo((u_long *)(addr+4),&tim1);

	// set the rect struct to contain the images x and y offset, width and height
	rect.x=tim1.px;
	rect.y=tim1.py;
	rect.w=tim1.pw;
	rect.h=tim1.ph;

	//load image from main memory to video memory
	LoadImage(&rect,tim1.pixel);

	// if image has clut we need to load it too,
	//pmode =8 for 4 bit and 9 for 8 bit colour

	if((tim1.pmode>>3)&0x01)
	{
		// set the rect struct to contain the clut's x and y offset, width and height
		rect.x=tim1.cx;
		rect.y=tim1.cy;
		rect.w=tim1.cw;
		rect.h=tim1.ch;
		// load the clut into video memeory
		LoadImage(&rect,tim1.clut);
	}
	DrawSync(0);
	return(0);
}

void InitialiseWorld ()
{
	int tmpx,tmpz;
	char c;
	//initialise total number of models to zero
	theWorld.nTotalModels=0;
	// load up the square1 texture to video memeory
	// LoadTexture(SQUARE1_TEX_MEM_ADDR);
	// then for each element of the worldGroundData array if we find a 1
	// then place an instance of square1.tmd at the appropriate position
	// in the world.
	for (tmpz = 0; tmpz < MAX_Z; tmpz++ ){
		for (tmpx = 0; tmpx < MAX_X; tmpx++ ){
			c= worldGroundData[tmpz][tmpx];
			if(c == '1')  {
				AddModelToWorld(&theWorld, (tmpz * SEPERATION),( 300),
						(tmpx * SEPERATION), (unsigned long *)SQUARE1_MEM_ADDR);
			} //end if
		}  //end for tmpx
	} //end for tmpz
}

void DrawWorld(WorldStructType0 *theWorld, GsOT *othWorld)
{
	MATRIX  tmpls, tmplw;
	int nCurrentModel;

	for (nCurrentModel = 0; nCurrentModel < theWorld->nTotalModels; nCurrentModel++)
	{
		//Get the local world and screen coordinates, needed for light calculations
		GsGetLws(theWorld->gsObjectHandler[nCurrentModel].coord2, &tmplw, &tmpls);
		// Set the resulting light source matrix
		GsSetLightMatrix(&tmplw);
		// Set the local screen matrix for the GTE (so it works out perspective etc)
		GsSetLsMatrix(&tmpls);
		// Send Object To Ordering Table
		GsSortObject4( &theWorld->gsObjectHandler[nCurrentModel], othWorld,	2,(u_long *)getScratchAddr(0));
	}
}

// This function associates a model with our player datastructure
// later we will want to add more than one model to the player
// to implement animation
void AddModelToObj(ObjStructType *obj, int nX, int nY, int nZ,
		unsigned long *lModelAddress)
{
	//increment the pointer to move past the model id. (weird huh?)
	lModelAddress++;
	// map tmd data to its actual address
	GsMapModelingData((unsigned long *)lModelAddress);
	// initialise the players coordinate system - set to be that of the world
	GsInitCoordinate2(WORLD, &obj->gsObjectCoord);
	// increment pointer twice more - to point to top of model data (beats me!)
	lModelAddress++;  lModelAddress++;
	// link the model (tmd) with the players object handler
	GsLinkObject4((unsigned long )lModelAddress, &obj->gsObjectHandler,0);
	// Assign the coordinates of the object model to the Object Handler
	obj->gsObjectHandler.coord2 = &obj->gsObjectCoord;
	// setting the players gsObjectCoord.flg to 0 indicates it is to be drawn
	// Set the initial position of the object
	obj->gsObjectCoord.coord.t[0]=nX;   // X
	obj->gsObjectCoord.coord.t[1]=nY;   // Y
	obj->gsObjectCoord.coord.t[2]=nZ;   // Z

	// setting the players gsObjectCoord.flg to 0 indicates it is to be drawn
	obj->gsObjectCoord.flg = 0;
}

void InitialiseObj(ObjStructType *obj, int nX, int nY, int nZ,
		unsigned long *lModelAddress)
{
	// initialise the players rotation vector to 0
	obj->rotation.vx=0;obj->rotation.vy=0;obj->rotation.vz=0;
	//initialise speed to 0
	obj->speed=0;
	// initialise other player variables and link in tmd
	AddModelToObj(obj,  nX, nY,nZ,(unsigned long *) lModelAddress); //-200
}

// This function deals with setting up matrices needed for rendering
// and sends the object to the ordering table so it will be drawn
void DrawObj(ObjStructType *obj, GsOT *othWorld)
{
	MATRIX  tmpls, tmplw;
	//Get the local world and screen coordinates, needed for light calculations
	GsGetLws(obj->gsObjectHandler.coord2, &tmplw, &tmpls);
	// Set the resulting light source matrix
	GsSetLightMatrix(&tmplw);
	// Set the local screen matrix for the GTE (so it works out perspective etc)
	GsSetLsMatrix(&tmpls);
	// Send Object To Ordering Table
	GsSortObject4( &obj->gsObjectHandler,othWorld, 3,(u_long *)getScratchAddr(0));

	// render debug 3d rect from 0,0,0 local space
	// GsSortObject4( &g_debug_obj_cube, othWorld,  3,(u_long *)getScratchAddr(0));
}


int process_player(player_t *player)
{
	int ret;
	TMDANIMHDR *anim_mgr;
	ret = 0;
	anim_mgr = player->anim_tmd;


	if(anim_mgr ==0 )
		return 0;

	player->frame_time++;
	LOG("%d %d - %d %d \n",player->frame_time, anim_mgr->frame_speed, 	player->frame_pos , anim_mgr->frames_cnt );


	if( player->frame_time > anim_mgr->frame_speed)
	{
		player->frame_time =0;
		player->frame_pos++;

		LOG("\nplayer->next_anim_p %d player->frame_pos %d  player->anim_cnt  %d \n",player->anim_tmd->next_anim_p , player->frame_pos,anim_mgr->frames_cnt );

		if( player->frame_pos == anim_mgr->frames_cnt)
		{


			player->frame_pos = 0;

			if(player->anim_tmd->next_anim_p) // dont loop, set next animation
			{
				LOG("\n anim needs to stop\n");
				ret = 1;
			}

			LOG("\n\n 222 process_player player->frame_pos %d   g_anim->frames_cnt %d\n",player->frame_pos, anim_mgr->frames_cnt );

			// LOG("process_with_normal_frame (list->vert_p)  0x%x  0x%x \n", (anim_mgr->anim->vert_p),*(anim_mgr->anim->vert_p));


		}

	}



	LOG("\n  process_with_normal_frame  sizeof(TMDANIMHDR)  0x%x  %d \n", sizeof(TMDANIMHDR),sizeof(TMDANIMHDR) );
	LOG("\n  process_with_normal_frame  ANIM_WALK  0x%x  %d \n", ANIM_WALK,ANIM_WALK );
	LOG("\n  process_with_normal_frame  ANIM_JUMP  0x%x  %d \n", ANIM_JUMP,ANIM_JUMP );

	LOG("\n  process_with_normal_frame  (u_long) anim_mgr    0x%x  (u_long) anim_mgr + sizeof(TMDANIMHDR)  0x%x  \n", (u_long) anim_mgr ,(u_long) anim_mgr + sizeof(TMDANIMHDR) );
	LOG("\n  process_with_normal_frame (list->vert_p)  0x%x  data 0x%x \n", (anim_mgr->vert_p), (u_long) *(anim_mgr->vert_p));

	LOG("\n  process_with_normal_frame (list->vert_p)  0x%x  0x%x \n", (anim_mgr->vert_p),*(anim_mgr->vert_p));

	// *(anim_mgr->anim->vert_p) = (u_long) anim_mgr->anim + sizeof(TMDANIMHDR) +  (u_long) ( anim_mgr->anim->total_size*player->frame_pos);

	// *(anim_mgr->vert_p) =   (u_long) anim_mgr + sizeof(TMDANIMHDR)  +     (u_long)     0 +  (u_long) ( anim_mgr->total_size*player->frame_pos);

	*(anim_mgr->vert_p) = (u_long) anim_mgr + sizeof(TMDANIMHDR)  +   (u_long) ( (anim_mgr->vert_size + anim_mgr->norm_size) *player->frame_pos);

			LOG("\n  process_with_normal_frame (list->vert_p)  0x%x  0x%x \n", (anim_mgr->vert_p),*(anim_mgr->vert_p));

	if(anim_mgr->norm_size)
		*(anim_mgr->normal_p) = (u_long) anim_mgr + sizeof(TMDANIMHDR)  +     (u_long)       anim_mgr->vert_size +  (u_long) ( (anim_mgr->vert_size + anim_mgr->norm_size)*player->frame_pos);


	anim_mgr->obj2_p->coord2 = &player->player_coord_loc;
	player->player_coord_loc.flg=0;


	return ret;

}


// This function deals with setting up matrices needed for rendering
// and sends the object to the ordering table so it will be drawn
void Draw_GsDOBJ2(GsDOBJ2  *obj, GsOT *othWorld)
{
	MATRIX  tmpls, tmplw;

	obj->coord2->flg =0;
	obj->coord2->super->flg =0;
	//Get the local world and screen coordinates, needed for light calculations
	GsGetLws(obj->coord2, &tmplw, &tmpls);
	// Set the resulting light source matrix
	GsSetLightMatrix(&tmplw);
	// Set the local screen matrix for the GTE (so it works out perspective etc)
	GsSetLsMatrix(&tmpls);
	// Send Object To Ordering Table
	GsSortObject4( obj,othWorld,  3,(u_long *)getScratchAddr(0));

}

// This function deals with double buffering and drawing of 3D objects
void RenderWorld(ObjStructType *obj,ObjStructType *ball1,ObjStructType *ball2,ObjStructType *ball3,WorldStructType0 *theWorld)
{
	// This variable keeps track of the current buffer for double buffering
	int currentBuffer;


	LOG("RenderWorld\n");
	//get the current buffer
	currentBuffer=GsGetActiveBuff();
	// Set the viewing system
	GsSetRefView2(&view);
	// Set the address of the packet area that will contain drawing commands
	GsSetWorkBase((PACKET*)out_packet[currentBuffer]);
	// clear the ordering table
	GsClearOt(0, 0, &othWorld[currentBuffer]);



	if(g_env_on)
	{
		// Draw the world
		DrawWorld(theWorld,  &othWorld[currentBuffer]);


		// rotate the root ball hierarchy, to make them all spin on top of the car
		RotateModel (&ball1->gsObjectCoord,&ball1->rotation, 0, 64, 0);

		// Draw the balls
		//	DrawObj(obj, &othWorld[currentBuffer]);




		if(g_box_on)
		{
			// Draw the player
			DrawObj(ball1, &othWorld[currentBuffer]);


			DrawObj(ball2, &othWorld[currentBuffer]);

			DrawObj(ball3, &othWorld[currentBuffer]);
		}




		//debug cube
#if 0

		{
			MATRIX  tmpls, tmplw;

			g_debug_obj_cube.coord2->flg = 0;
			GsGetLws(g_debug_obj_cube.coord2, &tmplw, &tmpls);
			// Set the resulting light source matrix
			GsSetLightMatrix(&tmplw);
			// Set the local screen matrix for the GTE (so it works out perspective etc)
			GsSetLsMatrix(&tmpls);
			// Send Object To Ordering Table
			GsSortObject4( &g_debug_obj_cube, &othWorld[currentBuffer],  3,(u_long *)getScratchAddr(0));
		}
#endif
	}

	// if(!g_pause_anim_on)
	{

		LOG("going process_player\n");

		if(process_player(&g_character))
		{
			LOG("stopped animation\n");
			g_character.anim_tmd=(TMDANIMHDR *)g_character.anim_tmd->next_anim_p; // replay anim

		}
	}


	// Draw_GsDOBJ2(&g_character.obj2, &othWorld[currentBuffer]);
	Draw_GsDOBJ2(g_character.anim_tmd->obj2_p, &othWorld[currentBuffer]);

	// render debug 3d debug rect in 0,0,0 local space from previous rendered obj - no coord2 or GsSetLsMatrix update needed
	if(g_box_on)
		GsSortObject4( &g_debug_obj_cube, &othWorld[currentBuffer],  3,(u_long *)getScratchAddr(0));


	// wait for end of drawing
	DrawSync(0);
	// wait for V_BLANK interrupt
	vsyncInterval=VSync(0);
	// print the vSync interval
	FntPrint("Vsyn:%x %x %d %d/%d %d:%d\n", *g_character.anim_tmd->vert_p ,*g_character.anim_tmd->normal_p , vsyncInterval,g_character.frame_pos+1, g_character.anim_tmd->frames_cnt, obj->gsObjectCoord.coord.t[0], obj->gsObjectCoord.coord.t[2]);
	// force text output
	FntFlush(-1);
	// Swap The Buffers
	GsSwapDispBuff();
	// register clear-command: clear to black
	GsSortClear(0,0,0,&othWorld[currentBuffer]);

	// register request to draw ordering table
	GsDrawOt(&othWorld[currentBuffer]);

}
/*
 *
 From Peter Passmore 3D course pdf page 15
 Setting up lighting is pretty straight forward, in fact its so easy we�ll have two. A light is
defined by the GsF_LIGHT struct which defines a light source by the direction in which it is
pointing, and it�s intensity expressed as a red, green, blue triple. Note these lights can be
considered to be infinitely far away, so we don�t specify their positions only the direction in
which they are emitting light. This direction is represented by a vector whose components
can be any size (ie: they are not normaliased values). We store our two lights in an array
defined as follows:
 *
 */
void InitialiseLight(GsF_LIGHT *flLight, int nLight,
		int nX, int nY, int nZ,
		int nRed, int nGreen, int nBlue)
{
	// Set the direction in which the light travels
	flLight->vx = nX;flLight->vy = nY;    flLight->vz = nZ;
	// Set the colour
	flLight->r = nRed; flLight->g = nGreen; flLight->b = nBlue;
	// Activate light
	GsSetFlatLight(nLight, flLight);
}

void InitialiseTrackerView(GsRVIEW2 *view, int nProjDist, int nRZ,
		int nVPX, int nVPY, int nVPZ,
		int nVRX, int nVRY, int nVRZ)
{
	// This is the distance between the eye
	// and the imaginary projection screen
	GsSetProjection(nProjDist);
	// Set the eye position or center of projection
	view->vpx = nVPX; view->vpy = nVPY;  view->vpz = nVPZ;
	// Set the look at position
	view->vrx = nVRX; view->vry = nVRY; view->vrz = nVRZ;
	// Set which way is up
	view->rz=-nRZ;
	// Set the origin of the coord system in this case the car
	view->super = &theModel.gsObjectCoord ;
	// Activate view
	GsSetRefView2(view);
}

void InitialiseStaticView(GsRVIEW2 *view, int nProjDist, int nRZ,
		int nVPX, int nVPY, int nVPZ,
		int nVRX, int nVRY, int nVRZ)
{
	// This is the distance between the eye
	// and the imaginary projection screen
	GsSetProjection(nProjDist);
	// Set the eye position or center of projection
	view->vpx = nVPX; view->vpy = nVPY;  view->vpz = nVPZ;
	// Set the look at position
	view->vrx = nVRX; view->vry = nVRY; view->vrz = nVRZ;
	// Set which way is up
	view->rz=-nRZ;
	// Set the origin of the coord system in this case the WORLD
	view->super = WORLD ;
	// Activate view
	GsSetRefView2(view);
}


void InitialiseAllLights()
{
	if(g_env_on)
	{
		//see for more information
		InitialiseLight(&flLights[0], 0,   			ONE, ONE, 0, 	 		0xff, 0x00, 0x00);  // light point location: +X right side, means shining to/on from -X left, and +Y down, means shining to/on from -Y, up
		InitialiseLight(&flLights[1], 1,   		-ONE, ONE, 0,    		0x00, 0x00, 0xff);  // light point location: +Y left side, means shining to/on from +X right, and +Y down, means shining to/on from -Y, up
		//InitialiseLight(&flLights[2], 2,      	0,  ONE, 0,     		0x11, 0x11, 0x11); // light point location: center, and +Y down, means shining down from -Y, center top, this is like a low ambient light
	}
	else
	{
		//white
		InitialiseLight(&flLights[0], 0,   			ONE, ONE, 0, 	 		0x88, 0x88, 0x88);  // light point location: +X right side, means shining to/on from -X left, and +Y down, means shining to/on from -Y, up
		InitialiseLight(&flLights[1], 1,   		-ONE, ONE, 0,    		0x88, 0x88, 0x88);  // light point location: +Y left side, means shining to/on from +X right, and +Y down, means shining to/on from -Y, up
		InitialiseLight(&flLights[2], 2,      	0,  ONE, 0,     		0x11, 0x11, 0x11); // light point location: center, and +Y down, means shining down from -Y, center top, this is like a low ambient light
	}

	// GsSetAmbient function notes:
	// light RGB in GsSetAmbient values are multiplied by the light GsF_LIGHT values for solid and interpolated coloured polygons, where the polygons are textured, the light values are applied to the pixels
	// From the ref doc, 100% correct light is: 4095, which would normally be 255 or 1.0 as a float value in openGL etc
	// 4095 (or ONE) are the default values, and are automatically set when never calling this function, or same as: GsSetAmbient(4095 ,4095 ,4095 );
	// GsSetAmbient, can be used to control all 3 lights in one function call... ie fade in and fade out transitions.


	// Values over 4095, will strengthen the light scene values and saturate close objects to their max colour values, ie GsSetAmbient(ONE<<4, ONE<<4, ONE<<4) and from my testing, ONE<<4 are the highest maximum values.
	// the lowest or darkest values are 	 GsSetAmbient(-1000 , -1000 , -1000 ); from my testing, -1000 are the minimum values

	// GsSetAmbient( ONE , ONE , ONE );



	if(g_env_on)//DO_FOG)
	{
		/*
		 *
From library ref: GsFOGPARAM
GsFOGPARAM describes fog (depth cue) information.
dqa and dqb are background colour attenuation coefficients.
They can be calculated using the following formulae:

dqa = -df * 4096/64/h
dqb = 1.25 * 4096 * 4096
df is the distance where the attenuation coefficient is 1; that is, the distance from the viewpoint to the point where the background colours are completely blended.
h is the distance from the viewpoint to the screen and is also known as the projection distance.

		 *
		 */
		//from survival
		/* Fog parameters for implementing depth cuing */
		GsFOGPARAM	FogParameters;
#define SCR_Z				256 //512 // not sure

		/* Near and Far clipping points on z axis */

#define	CLP_NEAR			128
#define	CLP_FAR				(2048*6)

		/* Set Fog parameters */

		// Parameter specifying the degree of blending with respect to near
		FogParameters.dqa = -CLP_FAR * ONE / 64 / SCR_Z;

		//	dqb Parameter specifying the degree of blending with respect to depth
		// example: dqb = 1.25 * 4096 * 4096
		FogParameters.dqb = ( ( (FOG_DEPTH)  * ONE) );

		FogParameters.rfc = FOG_RED;
		FogParameters.gfc = FOG_GREEN;
		FogParameters.bfc = FOG_BLUE;
		GsSetFogParam(&FogParameters);

		/* Set light mode - FOG on */
		GsSetLightMode(GsLMODE_FOG);
	}
	else
		GsSetLightMode(GsLMODE_LOFF);
}
void InitialiseGraphics()
{
	// Initialise The Graphics System to PAL as opposed to NTSC
	SetVideoMode(MODE_PAL);
	// The Actual Size of the Video memory
	GsInitGraph(SCREEN_WIDTH, SCREEN_HEIGHT, GsINTER|GsOFSGPU, 1, 0);
	// The Top Left Coordinates Of The Two Buffers
	GsDefDispBuff(0, 0, 0, SCREEN_HEIGHT);
	// Initialise the 3D Graphics...
	GsInit3D();
	// Before we can use the ordering table headers,
	// we need to...
	// 1. Set them to the right length
	othWorld[0].length = ORDERING_TABLE_LENGTH;
	othWorld[1].length = ORDERING_TABLE_LENGTH;
	// 2. Associate them with an actual ordering table
	othWorld[0].org = otWorld[0];
	othWorld[1].org = otWorld[1];
	// 3. initialise the World Ordering Table Headers and Arrays
	GsClearOt(0,0,&othWorld[0]);
	GsClearOt(0,0,&othWorld[1]);
}
void ResetMatrix(short m[3][3])
{
	m[0][0]=m[1][1]=m[2][2]=ONE;
	m[0][1]=m[0][2]=m[1][0]=m[1][2]=m[2][0]=m[2][1]=0;
}

// This rotation function avoids scaling problems that eventually occur from
// successive errors accumulating in the players matrix by cumulatively
// adding the angles in the players rotation vector and reseting the players
// matrix each time with the new cululative rotation angle
void RotateModel (GsCOORDINATE2 *gsObjectCoord,SVECTOR *rotateVector , int nRX, int nRY, int nRZ )
{
	MATRIX matTmp;
	// the reset the players coord system to the identity matrix
	ResetMatrix(gsObjectCoord->coord.m );
	// Add the new rotation factors into the players rotation vector
	// and then set them to the remainder of division by ONE (4096)
	rotateVector->vx = (rotateVector->vx+nRX)%ONE;
	rotateVector->vy = (rotateVector->vy+nRY)%ONE;
	rotateVector->vz = (rotateVector->vz+nRZ)%ONE;
	// RotMatrix sets up the matrix coefficients for rotation
	RotMatrix(rotateVector, &matTmp);
	// Concatenate the existing objects matrix with the rotation matrix
	MulMatrix0(&gsObjectCoord->coord, &matTmp, &gsObjectCoord->coord);
	// set the flag to redraw the object
	gsObjectCoord->flg = 0;
}

// move the model nD steps in the direction it is pointing
void AdvanceModel (GsCOORDINATE2 *gsObjectCoord, SVECTOR *rotateVector,
		long *speed, int nD)
{
	// Moves the model nD units in the direction of its rotation vector
	MATRIX matTmp;
	SVECTOR startVector;
	SVECTOR currentDirection;
	// if nD = 0 there is no movement and we need to avois the
	// main body of the function which will cause a divide by zero error
	if(nD!=0){
		// set up original vector, pointing down the positive z axis
		startVector.vx = 0; startVector.vy = 0;	startVector.vz = ONE;
		// RotMatrix sets up the matrix coefficients for rotation
		RotMatrix(rotateVector, &matTmp);
		// multiply startVector by mattmp and put the result in currentDirection
		// which is the vector defining the direction the player is pointing
		ApplyMatrixSV(&matTmp, &startVector, &currentDirection);
		// currentDirection components have a maximum value of 4096 so we
		// scale nD to 4096 /nD then when we add the amount of
		// translation we divide by nD. This ensures that we will translate
		// the number of units originally specified by nD
		// nD = 4096 /nD ;
		gsObjectCoord->coord.t[0] +=(currentDirection.vx * nD)/4096;
		gsObjectCoord->coord.t[1] +=(currentDirection.vy * nD)/4096;
		gsObjectCoord->coord.t[2] +=(currentDirection.vz * nD)/4096;
		// Because It Has Changed, 0 Means that we will redraw it
		gsObjectCoord->flg = 0;
		*speed; // need for CW
	} //end if
}



void ProcessUserInput()
{
	int speed_move = 10;
	int button_press=0;


	g_pause_anim_on=0;
	PADstatus=PadRead();

	if(PADstatus & PADselect)
	{
		FntPrint ( "Frame speed: %d Up/Down\n", g_character.anim_tmd->frame_speed);
		LOG ( "Frame speed: %d Up/Down\n", g_character.anim_tmd->frame_speed);
		g_pause_anim_on=1;

		if(PADstatus & PADLup)
		{
			if(g_character.anim_tmd->frame_speed == 255)
				g_character.anim_tmd->frame_speed=0;
			else
				g_character.anim_tmd->frame_speed++;

			button_press = PADLup;
			PADstatus = 0; //clear all select and up/down - dont do anything else!

		}
		if(PADstatus & PADLdown)
		{
			if(g_character.anim_tmd->frame_speed == 0)
				g_character.anim_tmd->frame_speed=255;
			else
				g_character.anim_tmd->frame_speed--;

			button_press = PADLdown;
			PADstatus = 0; //clear all select and up/down - dont do anything else!

		}

	} // select


	{
		if(PADstatus & PADstart)
		{
			FntPrint ( "PAD start: reset %x\n", g_character.anim_tmd->vert_p);
			theModel.gsObjectCoord.coord=GsIDMATRIX;
			theModel.gsObjectCoord.coord.t[1]=-20;
			theModel.speed=0;
			theModel.rotation.vx=0;  theModel.rotation.vy=0;  theModel.rotation.vy=0;
			theModel.gsObjectCoord.flg=0;

			if(PADstatus & PADselect)
			{
				FntPrint("PAD start + select: shutdown! \n" );
				PLAYING=0;
			}

			g_character.frame_time = g_character.frame_pos =0;

			if(g_character.anim_tmd == 0)
				g_character.anim_tmd=g_character.anim_next_p; // replay anim


			button_press = PADstart;
			if(g_character.anim_tmd == g_anim_jump)
			{
				LOG ( "PAD start: reset g_character.anim_tmd == g_anim_jump\n");

				LOG ( "g_character.anim_tmd %d 0x%x\n",g_character.anim_tmd, g_character.anim_tmd);
				g_character.anim_tmd  = (TMDANIMHDR *)g_anim_walk;
				LOG ( "g_character.anim_tmd %d 0x%x\n",g_character.anim_tmd, g_character.anim_tmd);

				LOG ( "g_character.anim_tmd vert_p %d 0x%x\n",g_character.anim_tmd->vert_p, g_character.anim_tmd->vert_p);

				LOG ( "g_character.anim_tmd vert_p %d 0x%x\n",*g_character.anim_tmd->vert_p, *g_character.anim_tmd->vert_p);


				//g_character.anim_tmd->start_p =(u_long *)( (u_long)g_character.anim_tmd +(u_long)sizeof(TMDANIMHDR));

				g_character.anim_next_p =g_character.anim_tmd;
			}
			else
			{
				LOG ( "PAD start: reset g_character.anim_tmd != g_anim_jump\n");

				LOG ( "PAD start: g_character.anim_tmd %d 0x%x\n",g_character.anim_tmd, g_character.anim_tmd);
				LOG ( "g_character.anim_tmd vert_p %d 0x%x\n",g_character.anim_tmd->vert_p, g_character.anim_tmd->vert_p);
				LOG ( "g_character.anim_tmd vert_p %d 0x%x\n",g_character.anim_tmd->vert_p, g_character.anim_tmd->vert_p);
				LOG ( "PAD start: reset g_character.anim_tmd  = (TMDANIMHDR *)g_anim_jump;  g_anim_jump = %d 0x%x \n", g_anim_jump, g_anim_jump);
				g_character.anim_tmd  = (TMDANIMHDR *)g_anim_jump;
				//g_character.anim_tmd->start_p =(u_long *)( (u_long)g_character.anim_tmd +(u_long)sizeof(TMDANIMHDR));
				LOG ( "g_character.anim_tmd %d 0x%x\n",g_character.anim_tmd, g_character.anim_tmd);

				LOG ( "g_character.anim_tmd vert_p %d 0x%x\n",g_character.anim_tmd->vert_p, g_character.anim_tmd->vert_p);

				LOG ( "g_character.anim_tmd vert_p %d 0x%x\n",*g_character.anim_tmd->vert_p, *g_character.anim_tmd->vert_p);

				g_character.anim_next_p =g_character.anim_tmd;

			}

		} // start

		if (PADstatus & PADL1){
			FntPrint ( "PAD padL1:STATIC_VIEW\n");
			InitialiseStaticView(&view, 250, 0,
					0, g_min_max->min.vy +-500,-1000,
					theModel.gsObjectCoord.coord.t[0], theModel.gsObjectCoord.coord.t[1], theModel.gsObjectCoord.coord.t[2] );
		}
		if (PADstatus & PADL2)
		{
			FntPrint ( "PAD padR1: TRACKER_VIEW!\n");
			InitialiseTrackerView(&view, 250, 0,
					0, g_min_max->min.vy *6, -(g_min_max->max.vz *4),
					0, 200, 0 );
		}
		if (PADstatus & PADR2)
		{
			FntPrint ( "PAD padR2: debug box!\n");
			g_box_on = ~g_box_on;
			button_press = PADR2;
		}
		if (PADstatus & PADR1)
		{
			FntPrint ( "PAD padR1: evn!\n");
			g_env_on = ~g_env_on;
			InitialiseAllLights();
			button_press = PADR1;

		}

		if(PADstatus & PADRup)
		{

			// Set the eye position up
			view.vpy-=speed_move; //neg is Y up

			// Activate view
			GsSetRefView2(&view);


		}
		if(PADstatus & PADRdown)
		{

			// Set the eye position down
			view.vpy+=speed_move;

			// Activate view
			GsSetRefView2(&view);
		}

		if(PADstatus & PADRleft)
		{

			// Set the eye position z
			view.vpz+=speed_move;

			// Activate view
			GsSetRefView2(&view);
		}
		if(PADstatus & PADRright)
		{

			// Set the eye position z
			view.vpz-=speed_move;

			// Activate view
			GsSetRefView2(&view);
		}

		if(PADstatus & PADLleft){

			FntPrint( "Left Arrow: Rotate Left\n");
			RotateModel (&theModel.gsObjectCoord,&theModel.rotation,0,-64,-0);
		}
		if(PADstatus & PADLright){

			FntPrint ( "Right Arrow: Rotate Right\n");
			RotateModel (&theModel.gsObjectCoord,&theModel.rotation,  0, 64, 0 );
		}

		if(PADstatus & PADLup)// PADcross)
		{
			FntPrint ( "PAD cross: Move Forward\n");
			AdvanceModel(&theModel.gsObjectCoord,&theModel.rotation,&theModel.speed,64);
		}
		if (PADstatus & PADLdown) //PADsquare)
		{
			FntPrint ( "PAD square Move Backward\n");
			AdvanceModel(&theModel.gsObjectCoord,&theModel.rotation,&theModel.speed,-64);
			// MoveModel(&theModel.gsObjectCoord,0,0,-32);

		}

	}

	if( button_press)
	{

		LOG("\nbutton_press %d \n", button_press);
		PADstatus=PadRead();
		while ((PADstatus & button_press))
		{
			PADstatus=PadRead();
			LOG(".");
		}
	}

}




#if 0
MATRIX  tmpls, tmplw;
//Get the local world and screen coordinates, needed for light calculations
GsGetLws(obj->gsObjectHandler.coord2, &tmplw, &tmpls);
// Set the resulting light source matrix
GsSetLightMatrix(&tmplw);
// Set the local screen matrix for the GTE (so it works out perspective etc)
GsSetLsMatrix(&tmpls);
// Send Object To Ordering Table
GsSortObject4( &obj->gsObjectHandler,othWorld, 3,(u_long *)getScratchAddr(0));
#endif


#if 0
TMD_FLAT_3D_RECT *debug_create_rect(u_short WIDTH,  u_short HIEGHT, u_short DEPTH ,   GsDOBJ2 *obj_rect, GsCOORDINATE2 * coord2_p)
{
	TMD_FLAT_3D_RECT *tmd_rect;
	GsCOORDINATE2 	tmd_coord={0};
	u_long *lModelAddress;


	short X_RIGHT = WIDTH;
	short X_LEFT = -WIDTH;

	short Y_TOP = -HIEGHT;
	short Y_BOT =HIEGHT;

	short Z_FAR = DEPTH;
	short Z_NEAR = -DEPTH;


#define FACE_R 254
#define FACE_G 254
#define FACE_B 254


	tmd_rect = (TMD_FLAT_3D_RECT *) calloc(  sizeof(TMD_FLAT_3D_RECT), 1 );


	lModelAddress = (u_long *)tmd_rect;



	setTMD_HEADER_INIT_IN_RAM(&tmd_rect->tmd_hdr);

#if 0
	setTMD_OBJ_TABLE( &tmd_rect->obj_table,
			( (u_long)(&tmd_rect->vert_data) - (u_long)(&tmd_rect->obj_table) ), 8,
			0, 0,
			( (u_long)(&tmd_rect->prim_data) - (u_long)(&tmd_rect->obj_table) ), 8 ,
			1);

	setTMD_OBJ(obj_table,
			vert_table, (gridw + 1) * (gridh + 1),
			norm_table, 0,
			prim_table, 2 * gridw * gridh,
			0);

#else

	setTMD_OBJ_TABLE( &tmd_rect->obj_table,
			( (u_long)(&tmd_rect->vert_data[0]) ), 8,
			( (u_long)(&tmd_rect->vert_data[0]) ), 0,
			( (u_long)(&tmd_rect->prim_data[0]) ), 6 ,
			0);
#endif

	setPRIM_HDR(&tmd_rect->prim_data[0].hdr, F_4_NL, 1, 3, 5);
	setPRIM_HDR(&tmd_rect->prim_data[1].hdr, F_4_NL, 1, 3, 5);
	setPRIM_HDR(&tmd_rect->prim_data[2].hdr, F_4_NL, 1, 3, 5);
	setPRIM_HDR(&tmd_rect->prim_data[3].hdr, F_4_NL, 1, 3, 5);
	setPRIM_HDR(&tmd_rect->prim_data[4].hdr, F_4_NL, 1, 3, 5);
	setPRIM_HDR(&tmd_rect->prim_data[5].hdr, F_4_NL, 1, 3, 5);


	// (p)->mode = (_m), (p)->flag = (_f), (p)->ilen = (_i), (p)->olen = (_o)


	// 0; left bot NEAR
	tmd_rect->vert_data[0].vx = X_LEFT ;
	tmd_rect->vert_data[0].vy = Y_BOT ;
	tmd_rect->vert_data[0].vz = Z_NEAR ;

	// 1;   left bot FAR
	tmd_rect->vert_data[1].vx = X_LEFT ;
	tmd_rect->vert_data[1].vy = Y_BOT ;
	tmd_rect->vert_data[1].vz = Z_FAR ;

	// 2;   right bot Far
	tmd_rect->vert_data[2].vx = X_RIGHT ;
	tmd_rect->vert_data[2].vy = Y_BOT ;
	tmd_rect->vert_data[2].vz = Z_FAR ;

	// 3; right bot NEAR
	tmd_rect->vert_data[3].vx = X_RIGHT ;
	tmd_rect->vert_data[3].vy = Y_BOT ;
	tmd_rect->vert_data[3].vz = Z_NEAR ;


	// 4; left  top NEAR
	tmd_rect->vert_data[4].vx = X_LEFT ;
	tmd_rect->vert_data[4].vy = Y_TOP ;
	tmd_rect->vert_data[4].vz = Z_NEAR ;

	// 5;   left top FAR
	tmd_rect->vert_data[5].vx = X_LEFT ;
	tmd_rect->vert_data[5].vy = Y_TOP ;
	tmd_rect->vert_data[5].vz = Z_FAR ;

	// 6;   right top Far
	tmd_rect->vert_data[6].vx = X_RIGHT ;
	tmd_rect->vert_data[6].vy = Y_TOP ;
	tmd_rect->vert_data[6].vz = Z_FAR ;

	// 7; right top NEAR
	tmd_rect->vert_data[7].vx = X_RIGHT ;
	tmd_rect->vert_data[7].vy = Y_TOP ;
	tmd_rect->vert_data[7].vz = Z_NEAR ;


	//faces
	tmd_rect->prim_data[0].data.vert0 = 2;
	tmd_rect->prim_data[0].data.vert1 = 1;
	tmd_rect->prim_data[0].data.vert2 = 3;
	tmd_rect->prim_data[0].data.vert3 = 0;

	tmd_rect->prim_data[1].data.vert0 = 4;
	tmd_rect->prim_data[1].data.vert1 = 0;
	tmd_rect->prim_data[1].data.vert2 = 5;
	tmd_rect->prim_data[1].data.vert3 = 1;

	tmd_rect->prim_data[2].data.vert0 = 5;
	tmd_rect->prim_data[2].data.vert1 = 1;
	tmd_rect->prim_data[2].data.vert2 = 6;
	tmd_rect->prim_data[2].data.vert3 = 2;

	tmd_rect->prim_data[3].data.vert0 = 6;
	tmd_rect->prim_data[3].data.vert1 = 2;
	tmd_rect->prim_data[3].data.vert2 = 7;
	tmd_rect->prim_data[3].data.vert3 = 3;

	tmd_rect->prim_data[4].data.vert0 = 7;
	tmd_rect->prim_data[4].data.vert1 = 3;
	tmd_rect->prim_data[4].data.vert2 = 4;
	tmd_rect->prim_data[4].data.vert3 = 0;

	tmd_rect->prim_data[5].data.vert0 = 7;
	tmd_rect->prim_data[5].data.vert1 = 4;
	tmd_rect->prim_data[5].data.vert2 = 6;
	tmd_rect->prim_data[5].data.vert3 = 5;



	tmd_rect->prim_data[0].data.r0 =FACE_R;
	tmd_rect->prim_data[0].data.g0 =0;
	tmd_rect->prim_data[0].data.b0 =0;

	tmd_rect->prim_data[1].data.r0 =0;
	tmd_rect->prim_data[1].data.g0 =FACE_G;
	tmd_rect->prim_data[1].data.b0 =0;

	tmd_rect->prim_data[2].data.r0 =0;
	tmd_rect->prim_data[2].data.g0 =0;
	tmd_rect->prim_data[2].data.b0 =FACE_B;

	tmd_rect->prim_data[3].data.r0 =0;
	tmd_rect->prim_data[3].data.g0 =FACE_G;
	tmd_rect->prim_data[3].data.b0 =FACE_B;

	tmd_rect->prim_data[4].data.r0 =FACE_R;
	tmd_rect->prim_data[4].data.g0 =0;
	tmd_rect->prim_data[4].data.b0 =FACE_B;

	tmd_rect->prim_data[5].data.r0 =FACE_R;
	tmd_rect->prim_data[5].data.g0 =FACE_G;
	tmd_rect->prim_data[5].data.b0 =0;



	tmd_rect->prim_data[0].data.mode2 = 0x29;
	tmd_rect->prim_data[1].data.mode2 = 0x29;
	tmd_rect->prim_data[2].data.mode2 = 0x29;
	tmd_rect->prim_data[3].data.mode2 = 0x29;
	tmd_rect->prim_data[4].data.mode2 = 0x29;
	tmd_rect->prim_data[5].data.mode2 = 0x29;


#if 0

#define setTMD_OBJ_TABLE(t,
	_vt,_vn, // verts

	_nt,_nn, // norms
	_pt,_pn, // prims
	_s) \
		(t)->vert_top = (_vt), (t)->n_vert = (_vn),	\
		(t)->norm_top = (_nt), (t)->n_norm = (_nn),	\
		(t)->prim_top = (_pt), (t)->n_prim = (_pn),	\
		(t)->scale = (_s)

		typedef struct
		{
		TMD_HEADER tmd_hdr;
		TMD_OBJ_TABLE obj_table;
		PRIM_HDR prim_table;
		TMD_F_4 prim_data[8];
		TMD_SVECTOR vert_data[8];
		} TMD_FLAT_3D_RECT;

#endif


		if(1)
		{
			int cnter;
			long *p= ( long *)&tmd_rect;
			//	printf("\n\n\n\n sizeof(TMD_FLAT_3D_RECT) %d\n\n\n", sizeof(TMD_FLAT_3D_RECT));

			for(cnter=0; cnter<sizeof(TMD_FLAT_3D_RECT)/4; cnter++)
			{
				if(!(cnter%4) )
					printf("\n");

				//printf("  %d, %d, %d, %d, \n", p[3], p[2], p[1], p[0]);
				printf("  0x%x, ", *p);
				p++;

			}
		}
		//	printf("\n\n\n\n sizeof(TMD_FLAT_3D_RECT) %d 0x%x  \n\n\n", sizeof(TMD_FLAT_3D_RECT), &tmd_rect);




		// print_cube(&tmd_rect);


		//increment the pointer to move past the model id. (weird huh?)
		// skip ID in header
		lModelAddress++;

		// map tmd data to its actual address
		GsMapModelingData((unsigned long *)lModelAddress);

		// initialise the players coordinate system - set to be that of the world
		GsInitCoordinate2(WORLD, coord2_p);

		// increment pointer twice more - to point to top of model data (beats me!)
		// skip flags and nobjs in header - points to (first) obj table
		lModelAddress++;  lModelAddress++;


		// link the model (tmd) with the players object handler
		GsLinkObject4((unsigned long )lModelAddress, obj_rect,0);

		// Assign the coordinates of the object model to the Object Handler
		obj_rect->coord2 =coord2_p;

#if 0 //display stuff
		tmd_coord.coord.t[1] = -722;

		obj_rect.coord2 = &tmd_coord;
		obj_rect.coord2->flg =0;
		obj_rect.coord2->super = obj->coord2;

		GsGetLws(obj_rect.coord2, &tmplw, &tmpls);
		// Set the resulting light source matrix
		GsSetLightMatrix(&tmplw);
		// Set the local screen matrix for the GTE (so it works out perspective etc)
		GsSetLsMatrix(&tmpls);

		GsSortObject4( &obj_rect,othWorld,  3,(u_long *)getScratchAddr(0));
#endif


		//	print_cube(&tmd_rect);

		return tmd_rect;
}


#else


// TOP_XYZ: Top corner of rectangle.
// BOT_XYZ: Bottom corner of rectangle.
// Note: XYZ values above are in local space and converted to world space via coord2 and GsSetLsMatrix, it can also be used without coord when rendering other objects.
// RGB: set single colour for all faces, if RGB are all zero's it will auto colour each face.
// obj2 is linked to TMD and coord2 is cleared and set to obj2.
// Return: The TMD_FLAT_3D_RECT pointer returned should be free(); on exit.
// TMD faces/winding is probably not correct
TMD_FLAT_3D_RECT *debug_create_rect(short top_X,  short top_Y, short top_Z,   short bot_X,  short bot_Y, short bot_Z, char r, char b, char g,     GsDOBJ2 *obj_rect, GsCOORDINATE2 * coord2_p)
{
	TMD_FLAT_3D_RECT *tmd_rect;
	GsCOORDINATE2 	tmd_coord={0};
	u_long *lModelAddress;
	u_long alloc_size;


	LOG("debug_create_rect top %d,%d,%d bot: %d,%d,%d \n",  top_X,top_Y, top_Z, bot_X, bot_Y, bot_Z);


	alloc_size = sizeof(TMD_FLAT_3D_RECT);

	alloc_size += alloc_size%32; // just in case!
	LOG("debug_create_rect RAM allocation:%d \n",  alloc_size );


	tmd_rect = (TMD_FLAT_3D_RECT *) calloc(alloc_size, 1);

	if(!tmd_rect)
		return NULL;

	lModelAddress = (u_long *)tmd_rect;
	setTMD_HEADER_DEFAULTS(&tmd_rect->tmd_hdr);

	setTMD_OBJ_TABLE( &tmd_rect->obj_table,
			( (u_long)(&tmd_rect->vert_data[0]) ), 8,
			( (u_long)(&tmd_rect->vert_data[0]) ), 0,
			( (u_long)(&tmd_rect->prim_data[0]) ), 6 ,
			0);

	setPRIM_HDR(&tmd_rect->prim_data[0].hdr, F_4_NL, 1, 3, 5);
	setPRIM_HDR(&tmd_rect->prim_data[1].hdr, F_4_NL, 1, 3, 5);
	setPRIM_HDR(&tmd_rect->prim_data[2].hdr, F_4_NL, 1, 3, 5);
	setPRIM_HDR(&tmd_rect->prim_data[3].hdr, F_4_NL, 1, 3, 5);
	setPRIM_HDR(&tmd_rect->prim_data[4].hdr, F_4_NL, 1, 3, 5);
	setPRIM_HDR(&tmd_rect->prim_data[5].hdr, F_4_NL, 1, 3, 5);


	// 0; left bot NEAR
	tmd_rect->vert_data[0].vx = top_X; // X_LEFT ;
	tmd_rect->vert_data[0].vy = bot_Y; // Y_BOT ;
	tmd_rect->vert_data[0].vz = top_Z; //Z_NEAR ;

	// 1;   left bot FAR
	tmd_rect->vert_data[1].vx = top_X; //X_LEFT ;
	tmd_rect->vert_data[1].vy = bot_Y; // Y_BOT ;
	tmd_rect->vert_data[1].vz = bot_Z; // Z_FAR ;

	// 2;   right bot Far
	tmd_rect->vert_data[2].vx = bot_X; //X_RIGHT ;
	tmd_rect->vert_data[2].vy = bot_Y; //Y_BOT ;
	tmd_rect->vert_data[2].vz = bot_Z; //Z_FAR ;


	// 3; right bot NEAR
	tmd_rect->vert_data[3].vx = bot_X; //X_RIGHT ;
	tmd_rect->vert_data[3].vy = bot_Y; //Y_BOT ;
	tmd_rect->vert_data[3].vz = top_Z; //Z_NEAR ;


	// 4; left  top NEAR
	tmd_rect->vert_data[4].vx = top_X; //X_LEFT ;
	tmd_rect->vert_data[4].vy = top_Y; //Y_TOP ;
	tmd_rect->vert_data[4].vz = top_Z; //Z_NEAR ;


	// 5;   left top FAR
	tmd_rect->vert_data[5].vx = top_X; //X_LEFT ;
	tmd_rect->vert_data[5].vy = top_Y; //Y_TOP ;
	tmd_rect->vert_data[5].vz = bot_Z; // Z_FAR ;

	// 6;   right top Far
	tmd_rect->vert_data[6].vx = bot_X; //X_RIGHT ;
	tmd_rect->vert_data[6].vy = top_Y; //Y_TOP ;
	tmd_rect->vert_data[6].vz = bot_Z; //Z_FAR ;


	// 7; right top NEAR
	tmd_rect->vert_data[7].vx = bot_X; //X_RIGHT ;
	tmd_rect->vert_data[7].vy = top_Y; //Y_TOP ;
	tmd_rect->vert_data[7].vz = top_Z; //Z_NEAR ;


	//faces
	tmd_rect->prim_data[0].data.vert0 = 2;
	tmd_rect->prim_data[0].data.vert1 = 1;
	tmd_rect->prim_data[0].data.vert2 = 3;
	tmd_rect->prim_data[0].data.vert3 = 0;

	tmd_rect->prim_data[1].data.vert0 = 4;
	tmd_rect->prim_data[1].data.vert1 = 0;
	tmd_rect->prim_data[1].data.vert2 = 5;
	tmd_rect->prim_data[1].data.vert3 = 1;

	tmd_rect->prim_data[2].data.vert0 = 5;
	tmd_rect->prim_data[2].data.vert1 = 1;
	tmd_rect->prim_data[2].data.vert2 = 6;
	tmd_rect->prim_data[2].data.vert3 = 2;

	tmd_rect->prim_data[3].data.vert0 = 6;
	tmd_rect->prim_data[3].data.vert1 = 2;
	tmd_rect->prim_data[3].data.vert2 = 7;
	tmd_rect->prim_data[3].data.vert3 = 3;

	tmd_rect->prim_data[4].data.vert0 = 7;
	tmd_rect->prim_data[4].data.vert1 = 3;
	tmd_rect->prim_data[4].data.vert2 = 4;
	tmd_rect->prim_data[4].data.vert3 = 0;

	tmd_rect->prim_data[5].data.vert0 = 7;
	tmd_rect->prim_data[5].data.vert1 = 4;
	tmd_rect->prim_data[5].data.vert2 = 6;
	tmd_rect->prim_data[5].data.vert3 = 5;


	if(r == g == b == 0) // multi colour!
	{
		tmd_rect->prim_data[0].data.r0 =255;
		tmd_rect->prim_data[0].data.g0 =0;
		tmd_rect->prim_data[0].data.b0 =0;

		tmd_rect->prim_data[1].data.r0 =0;
		tmd_rect->prim_data[1].data.g0 =255;
		tmd_rect->prim_data[1].data.b0 =0;

		tmd_rect->prim_data[2].data.r0 =0;
		tmd_rect->prim_data[2].data.g0 =0;
		tmd_rect->prim_data[2].data.b0 =255;

		tmd_rect->prim_data[3].data.r0 =0;
		tmd_rect->prim_data[3].data.g0 =255;
		tmd_rect->prim_data[3].data.b0 =255;

		tmd_rect->prim_data[4].data.r0 =255;
		tmd_rect->prim_data[4].data.g0 =0;
		tmd_rect->prim_data[4].data.b0 =255;

		tmd_rect->prim_data[5].data.r0 =255;
		tmd_rect->prim_data[5].data.g0 =255;
		tmd_rect->prim_data[5].data.b0 =0;

	}
	else // solid RGB
	{
		tmd_rect->prim_data[0].data.r0 =r;
		tmd_rect->prim_data[0].data.g0 =g;
		tmd_rect->prim_data[0].data.b0 =b;

		tmd_rect->prim_data[1].data.r0 =r;
		tmd_rect->prim_data[1].data.g0 =g;
		tmd_rect->prim_data[1].data.b0 =b;

		tmd_rect->prim_data[2].data.r0 =r;
		tmd_rect->prim_data[2].data.g0 =g;
		tmd_rect->prim_data[2].data.b0 =b;

		tmd_rect->prim_data[3].data.r0 =r;
		tmd_rect->prim_data[3].data.g0 =g;
		tmd_rect->prim_data[3].data.b0 =b;

		tmd_rect->prim_data[4].data.r0 =r;
		tmd_rect->prim_data[4].data.g0 =g;
		tmd_rect->prim_data[4].data.b0 =b;

		tmd_rect->prim_data[5].data.r0 =r;
		tmd_rect->prim_data[5].data.g0 =g;
		tmd_rect->prim_data[5].data.b0 =b;
	}


	//not sure
	tmd_rect->prim_data[0].data.mode2 = 0x29;
	tmd_rect->prim_data[1].data.mode2 = 0x29;
	tmd_rect->prim_data[2].data.mode2 = 0x29;
	tmd_rect->prim_data[3].data.mode2 = 0x29;
	tmd_rect->prim_data[4].data.mode2 = 0x29;
	tmd_rect->prim_data[5].data.mode2 = 0x29;


	// print_cube(&tmd_rect);


	//increment the pointer to move past the model id. (weird huh?)
	// skip ID in header
	lModelAddress++;

	// map tmd data to its actual address
	GsMapModelingData((unsigned long *)lModelAddress);

	if(coord2_p)
	{
		// initialise the players coordinate system - set to be that of the world
		GsInitCoordinate2(WORLD, coord2_p);
	}
	else
		obj_rect->coord2 = WORLD; // NULL

	// increment pointer twice more - to point to top of model data (beats me!)
	// skip flags and nobjs in header - points to (first) obj table
	lModelAddress++;  lModelAddress++;


	// link the model (tmd) with the players object handler
	GsLinkObject4((unsigned long )lModelAddress, obj_rect,0);


	// Assign the coordinates of the object model to the Object Handler
	obj_rect->coord2 =coord2_p;

#if 0 //display test stuff
	tmd_coord.coord.t[1] = -722;

	obj_rect.coord2 = &tmd_coord;
	obj_rect.coord2->flg =0;
	obj_rect.coord2->super = obj->coord2;

	GsGetLws(obj_rect.coord2, &tmplw, &tmpls);
	// Set the resulting light source matrix
	GsSetLightMatrix(&tmplw);
	// Set the local screen matrix for the GTE (so it works out perspective etc)
	GsSetLsMatrix(&tmpls);

	GsSortObject4( &obj_rect,othWorld,  3,(u_long *)getScratchAddr(0));
#endif

	return tmd_rect;
}




#endif


GsDOBJ2 g_obj2_TMD;

TMD_HDR_OBJ *TMD;
SVECTOR * svect_p;
int main()
{
	int sign =1;


#ifdef DEBUG
	LOG = printf;
#else
	LOG = DUMMY;
#endif




	/*

 void InitHeap (
        void *head,
        long size
)

Arguments
head Pointer to heap start address
size Heap size (multiple of 4 bytes)

	The heap pointed to by head is initialized. Memory management functions are also initialized, so that malloc() and the other memory allocation functions can be used.
	The effective heap size is actually less than size because of overhead.
	Notes
	Multiple calls to InitHeap() are permitted only if they do not overlap, otherwise memory management functions will not operate properly
	 */

	LOG("Heap end (1st data) %#010x\n",  HEAP_SPACE);
	LOG("Heap start  (exe start)  %#010x\n",  FREE_SPACE);
	LOG("Stack size  %#010x %d /(1024*1024*1024) should equal 2mb \n\n",  FREE_SPACE - HEAP_SPACE, FREE_SPACE - HEAP_SPACE );

	InitHeap((unsigned long *)HEAP_SPACE, (unsigned long) FREE_SPACE - HEAP_SPACE);


	LOG("\n");

	//set min max - its used for view pos etc.
	// min most negative coord
	// max most positive coord
	// min y is up
	g_min_max = 	(TMD_MIN_MAX *)	F0_MM; // see dataman.txt F0 MinMax

	StartRCnt(1);        // not needed on Yaroze
	ResetRCnt(1);


	InitialiseGraphics();


	// set up print-to-screen font
	FntLoad(960, 256);
	FntOpen(-96, -96, 192, 192, 0, 512);
	// set up the controller pad
	PadInit();


#if 1
	InitialiseStaticView(&view, 250, 0,
			0, g_min_max->min.vy +-500,-1000,
			0, 0, 0 );
#else
	InitialiseTrackerView(&view, 250, 0,
			0, g_min_max->min.vy *6, -(g_min_max->max.vz *4),
			0, 200, 0 );
#endif
	InitialiseAllLights();


//	InitialiseObj(&theModel,  0, -10,0, (unsigned long*)  TMD_F1   );


	// init anim.mgr
	TMD = (TMD_HDR_OBJ *) (TMD_F1  );



	/*
Data having 32 bits (one word). Carries information on TIM data configuration. The least
significant bit is FIXP. The other bits are reserved and their values are all zero. The FIXP bit
indicates whether the pointer value of the OBJECT structure described later is a real address.
A value of one means a real address. A value of zero indicates the offset from the start.
	 */
#if 0

	//increment the pointer to move past the model id. (weird huh?)
	lModelAddress++;
	// map tmd data to its actual address
	GsMapModelingData((unsigned long *)lModelAddress);
	// initialise the players coordinate system - set to be that of the world
	GsInitCoordinate2(WORLD, &obj->gsObjectCoord);
	// increment pointer twice more - to point to top of model data (beats me!)
	lModelAddress++;  lModelAddress++;
	// link the model (tmd) with the players object handler
	GsLinkObject4((unsigned long )lModelAddress, &obj->gsObjectHandler,0);
	// Assign the coordinates of the object model to the Object Handler
	obj->gsObjectHandler.coord2 = &obj->gsObjectCoord;
	// setting the players gsObjectCoord.flg to 0 indicates it is to be drawn
	// Set the initial position of the object
	obj->gsObjectCoord.coord.t[0]=nX;   // X
	obj->gsObjectCoord.coord.t[1]=nY;   // Y
	obj->gsObjectCoord.coord.t[2]=nZ;   // Z

	// setting the players gsObjectCoord.flg to 0 indicates it is to be drawn
	obj->gsObjectCoord.flg = 0;
}
#endif

theModel.gsObjectCoord.flg = 0;

 if( (TMD->hdr.flag & 0x1) == 0 )
{
	unsigned long *lModelAddress = (unsigned long *) (TMD_F1  );
	//	GsCOORDINATE2 coordtmp;

	//increment the pointer to move past the model id. (weird huh?)
	lModelAddress++;
	// map tmd data to its actual address
	GsMapModelingData((unsigned long *)lModelAddress);
	// increment pointer twice more - to point to top of model data (beats me!)

	lModelAddress++;  lModelAddress++;
	// link the model (tmd) with the players object handler
	GsLinkObject4( (unsigned long )lModelAddress,  &g_obj2_TMD, 0);

	// set the amount of polygon subdivision that will be done at runtime (none!)
	g_obj2_TMD.attribute = GsDIV1;
	theModel.gsObjectCoord.flg = 0;
	// initialise the objects coordinate system - set to be that of the WORLD
		GsInitCoordinate2(WORLD,  &g_character.player_coord_loc);
		g_obj2_TMD.coord2 =  &g_character.player_coord_loc;



}

/*
g_character.anim_tmd  = (TMDANIMHDR *)g_anim_walk;
g_TMD_man.start_p =(u_long *)( (u_long)g_character.anim_tmd +(u_long)sizeof(TMDANIMHDR));
g_TMD_man.vert_p = &(TMD->obj.vert_top);
g_TMD_man.normal_p = &(TMD->obj.normal_top);
//g_TMD_man.anim_loop = g_TMD_man.loopback;
 *
 *
 *
g_TMD_man.anim = (TMDANIMHDR *)g_anim_jump;
g_TMD_man.anim->start_p =(u_long *)( (u_long)g_TMD_man.anim+(u_long)sizeof(TMDANIMHDR));
g_TMD_man.anim->vert_p = &(TMD->obj.vert_top);
g_TMD_man.anim->normal_p = &(TMD->obj.normal_top);
g_TMD_man.anim_loop = g_TMD_man.anim->loopback;
*/

g_anim_walk = (TMDANIMHDR *)ANIM_WALK;
LOG("g_anim_walk->version  %d \n", g_anim_walk->obj2_p);
g_anim_walk->next_anim_p = 0;//loop

LOG("g_anim_walk->vert_p  %d 0x%x \n", g_anim_walk->vert_p, g_anim_walk->vert_p);

g_anim_walk->obj2_p = &g_obj2_TMD;
g_anim_walk->vert_p =  &(TMD->obj.vert_top);
g_anim_walk->normal_p =  &(TMD->obj.normal_top);
LOG("g_anim_walk->vert_p  %d 0x%x \n", g_anim_walk->vert_p, g_anim_walk->vert_p);

g_anim_jump = (TMDANIMHDR *)ANIM_JUMP;
g_anim_jump->next_anim_p = (struct TMDANIMHDR_T *)g_anim_walk; //finished jump, do walk
LOG("g_anim_jump->version  %d \n", g_anim_jump->obj2_p);
g_anim_jump->obj2_p = &g_obj2_TMD;
g_anim_jump->vert_p = &(TMD->obj.vert_top);
g_anim_jump->normal_p =  &(TMD->obj.normal_top);

g_character.anim_tmd  = (TMDANIMHDR *)g_anim_walk;
g_character.anim_next_p  = (TMDANIMHDR *)g_anim_walk;


//copied to save a RAM call


g_character.player_coord_loc.flg =0;
g_character.frame_time = g_character.frame_pos =0;

theModel.gsObjectCoord.coord=GsIDMATRIX;
			theModel.gsObjectCoord.coord.t[1]=-20;
			theModel.speed=0;
			theModel.rotation.vx=0;  theModel.rotation.vy=0;  theModel.rotation.vy=0;
			theModel.gsObjectCoord.flg=0;


//LOG("\n\n HDR.loopback  player->anim_tmd->loopback %d\n", g_TMD_man.anim_loop);

//*(g_character.anim_tmd->vert_p) =   (u_long) ( (u_long) g_character.anim_tmd + sizeof(TMDANIMHDR) );



if(1)
{



	g_character.rot.vx=0;
	g_character.rot.vy=0;
	g_character.rot.vz=0;

	GsInitCoordinate2(&theModel.gsObjectCoord, &g_character.player_coord_loc);
	// increment pointer twice more - to point to top of model data (beats me!)
	// lModelAddress++;  lModelAddress++;
	// link the model (tmd) with the players object handler
	//GsLinkObject4((unsigned long *)lModelAddress, &obj->gsObjectHandler,0);

	// setting the players gsObjectCoord.flg to 0 indicates it is to be drawn
	// Set the initial position of the object
	g_character.player_coord_loc.coord.t[0]= 0;
	g_character.player_coord_loc.coord.t[1]= 0;
	g_character.player_coord_loc.coord.t[2]= 0;
	g_character.player_coord_loc.super = &theModel.gsObjectCoord ;
	g_character.frame_time =  0;

	// setting the players gsObjectCoord.flg to 0 indicates it is to be drawn
	g_character.player_coord_loc.flg = 0;
}
LOG("\n sizeof(TMDANIMHDR) %lu\n", sizeof(TMDANIMHDR));
#if 0


LOG("\n TMD addr 0x%0x %lu %lu\n", g_anim, g_anim, g_anim);
LOG("------TMD_HDR_OBJ DATA ----------\n");


LOG(" sizeof(TMD_HDR_OBJ) 0x%0x %lu  \n", sizeof(TMD_HDR_OBJ),  sizeof(TMD_HDR_OBJ) );
LOG(" start verts etc 0x%0x %lu  \n",(char*)g_anim+ sizeof(TMD_HDR_OBJ), (char*)g_anim+ sizeof(TMD_HDR_OBJ) );

LOG("1:frames_cnt 0x%0x %lu  \n", g_anim->frames_cnt, g_anim->frames_cnt );
LOG("2:top 0x%0x %lu  \n", g_anim->start_p, g_anim->start_p );

LOG("3:vert_size 0x%0x %lu  \n", g_anim->vert_size, g_anim->vert_size );
LOG("4:normal_size 0x%0x %lu  \n", g_anim->norm_size, g_anim->norm_size );



// list->TMD = (long*) ( (long)F1_DATA ) ;



LOG(" svect XYZ %d  %d %d \n", svect_p->vx , svect_p->vy , svect_p->vz);

LOG("------AFTER INIT TMD_HDR_OBJ DATA ----------\n");

LOG("1: frames_cnt 0x%0x %lu  \n", g_anim->frames_cnt, g_anim->frames_cnt );
LOG("2:top 0x%0x %lu  \n", g_anim->start_p, g_anim->start_p );
LOG("3:vert_size 0x%0x %lu  \n", g_anim->vert_size, g_anim->vert_size );
LOG("4:normal_size 0x%0x %lu  \n", g_anim->norm_size, g_anim->norm_size );


#endif





LOG("min max min %d,%d,%d max: %d,%d,%d \n",  g_min_max->min.vx,g_min_max->min.vy,g_min_max->min.vz, g_min_max->max.vx,g_min_max->max.vy,g_min_max->max.vz );

debug_create_rect( g_min_max->min.vx, g_min_max->min.vy, g_min_max->min.vz,   g_min_max->max.vx, g_min_max->max.vy, g_min_max->max.vz,   0,0,0,  &g_debug_obj_cube,  &g_debug_coord_cube);
// debug_create_rect(-20, -200, -20,    20, -420, 20,   0,0,0,  &g_debug_obj_cube,  &g_debug_coord_cube);



// print_cube(&MODEL00_TMD);

// up 220 from center of car
InitialiseObj(&ball1,   0, g_min_max->min.vy+-60,0, (unsigned long *)MODEL00_TMD);

// up and left from ball1
InitialiseObj(&ball2,    -g_min_max->max.vx+-60, -110, 0, (unsigned long *)MODEL00_TMD);

// up and right from ball1
InitialiseObj(&ball3,    g_min_max->max.vx+60, -110, 0, (unsigned long *)MODEL00_TMD);



// assign object hierarchy

//ball1 is child of car
ball1.gsObjectCoord.super = &theModel.gsObjectCoord;

//ball2 and ball3 are children of ball1
ball2.gsObjectCoord.super = &ball1.gsObjectCoord;
ball3.gsObjectCoord.super = &ball1.gsObjectCoord;

LoadTexture( (long)CAR_TEX_MEM_ADDR);
InitialiseWorld();






// coord2 not used or needed when using local space of another render object!
// g_debug_coord_cube.coord.t[1] = -211;
// g_debug_coord_cube.super = &ball1.gsObjectCoord;
//	print_cube(&tmd_rect);



// TMD_FLAT_3D_RECT *g_debug_tmd_cube_local;
// GsDOBJ2 g_debug_obj_cube_local={0};



while(PLAYING)
{




#if 1



#else
	g_frame+=2;


	if( (g_frame>>5) == g_anim->frames_cnt)
	{
		g_frame = 0;

	}

	process_frame(g_frame>>5, g_anim_mgr.anim);
#endif

	// process_frame_MIME(g_frame>>7,   (ONE),(long*) (F1_DATA) );

		theModel.gsObjectCoord.flg =0;
		ProcessUserInput();
		LOG("\n");



		LOGF( RenderWorld(&theModel,&ball1,&ball2,&ball3,&theWorld); );




}

free(g_debug_tmd_cube);

// clean up
ResetGraph(0);
return 0;
}



const unsigned char FLAT_TMD[272] = {
		0x41, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00, 0x94, 0x00, 0x00, 0x00,
		0x08, 0x00, 0x00, 0x00, 0xD4, 0x00, 0x00, 0x00, 0x06, 0x00, 0x00, 0x00, 0x1C, 0x00, 0x00, 0x00,
		0x06, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0x00, 0x80, 0x00, 0x28,
		0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x03, 0x00, 0x02, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0x00, 0x80, 0x00, 0x28, 0x01, 0x00, 0x04, 0x00, 0x05, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0x00, 0x80, 0x00, 0x28, 0x02, 0x00, 0x05, 0x00, 0x06, 0x00, 0x01, 0x00,
		0x02, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0x00, 0x80, 0x00, 0x28, 0x03, 0x00, 0x06, 0x00,
		0x07, 0x00, 0x02, 0x00, 0x03, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0x00, 0x80, 0x00, 0x28,
		0x04, 0x00, 0x07, 0x00, 0x04, 0x00, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0x00, 0x80, 0x00, 0x28, 0x05, 0x00, 0x07, 0x00, 0x06, 0x00, 0x04, 0x00, 0x05, 0x00, 0x00, 0x00,
		0x0C, 0xFE, 0xCE, 0xFF, 0x0C, 0xFE, 0x00, 0x00, 0x0C, 0xFE, 0xCE, 0xFF, 0xF4, 0x01, 0x00, 0x00,
		0xF4, 0x01, 0xCE, 0xFF, 0xF4, 0x01, 0x00, 0x00, 0xF4, 0x01, 0xCE, 0xFF, 0x0C, 0xFE, 0x00, 0x00,
		0x0C, 0xFE, 0x32, 0x00, 0x0C, 0xFE, 0x00, 0x00, 0x0C, 0xFE, 0x32, 0x00, 0xF4, 0x01, 0x00, 0x00,
		0xF4, 0x01, 0x32, 0x00, 0xF4, 0x01, 0x00, 0x00, 0xF4, 0x01, 0x32, 0x00, 0x0C, 0xFE, 0x00, 0x00,
		0x00, 0x00, 0x00, 0xF0, 0x00, 0x00, 0x00, 0x00, 0x00, 0xF0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0xF0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x00
};



/* Generated by bin2c, do not edit manually */

const unsigned char MODEL00_TMD[248] = {

		0x41, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00, 0x7C, 0x00, 0x00, 0x00,
		0x08, 0x00, 0x00, 0x00, 0xBC, 0x00, 0x00, 0x00, 0x06, 0x00, 0x00, 0x00, 0x1C, 0x00, 0x00, 0x00,
		0x06, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x05, 0x03, 0x01, 0x29, 0x40, 0x40, 0xFF, 0x29,
		0x00, 0x00, 0x01, 0x00, 0x03, 0x00, 0x02, 0x00, 0x05, 0x03, 0x01, 0x29, 0x40, 0x40, 0xFF, 0x29,
		0x04, 0x00, 0x05, 0x00, 0x00, 0x00, 0x01, 0x00, 0x05, 0x03, 0x01, 0x29, 0x40, 0x40, 0xFF, 0x29,
		0x05, 0x00, 0x06, 0x00, 0x01, 0x00, 0x02, 0x00, 0x05, 0x03, 0x01, 0x29, 0x40, 0x40, 0xFF, 0x29,
		0x06, 0x00, 0x07, 0x00, 0x02, 0x00, 0x03, 0x00, 0x05, 0x03, 0x01, 0x29, 0x40, 0x40, 0xFF, 0x29,
		0x07, 0x00, 0x04, 0x00, 0x03, 0x00, 0x00, 0x00, 0x05, 0x03, 0x01, 0x29, 0x40, 0x40, 0xFF, 0x29,
		0x07, 0x00, 0x06, 0x00, 0x04, 0x00, 0x05, 0x00, 0xCE, 0xFF, 0xCE, 0xFF, 0xCE, 0xFF, 0x00, 0x00,
		0xCE, 0xFF, 0xCE, 0xFF, 0x32, 0x00, 0x00, 0x00, 0x32, 0x00, 0xCE, 0xFF, 0x32, 0x00, 0x00, 0x00,
		0x32, 0x00, 0xCE, 0xFF, 0xCE, 0xFF, 0x00, 0x00, 0xCE, 0xFF, 0x32, 0x00, 0xCE, 0xFF, 0x00, 0x00,
		0xCE, 0xFF, 0x32, 0x00, 0x32, 0x00, 0x00, 0x00, 0x32, 0x00, 0x32, 0x00, 0x32, 0x00, 0x00, 0x00,
		0x32, 0x00, 0x32, 0x00, 0xCE, 0xFF, 0x00, 0x00, 0x00, 0x00, 0x00, 0xF0, 0x00, 0x00, 0x00, 0x00,
		0x00, 0xF0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 0x00, 0x00,
		0x00, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xF0, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x00

};

/* Generated by bin2c, do not edit manually */

const unsigned char CAR01_TMD[9120] = {
		0x41, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00, 0x4C, 0x15, 0x00, 0x00,
		0xFA, 0x00, 0x00, 0x00, 0x1C, 0x1D, 0x00, 0x00, 0xCF, 0x00, 0x00, 0x00, 0x1C, 0x00, 0x00, 0x00,
		0x0E, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28,
		0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x02, 0x00, 0x02, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0xC8, 0xC8, 0xC8, 0x28, 0x00, 0x00, 0x00, 0x00, 0x03, 0x00, 0x01, 0x00, 0x01, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28, 0x00, 0x00, 0x00, 0x00, 0x04, 0x00, 0x03, 0x00,
		0x03, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28, 0x00, 0x00, 0x00, 0x00,
		0x05, 0x00, 0x04, 0x00, 0x04, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28,
		0x00, 0x00, 0x00, 0x00, 0x06, 0x00, 0x05, 0x00, 0x05, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0xC8, 0xC8, 0xC8, 0x28, 0x00, 0x00, 0x00, 0x00, 0x07, 0x00, 0x06, 0x00, 0x06, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00, 0x07, 0x00,
		0x07, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28, 0x00, 0x00, 0x00, 0x00,
		0x02, 0x00, 0x08, 0x00, 0x08, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28,
		0x01, 0x00, 0x02, 0x00, 0x01, 0x00, 0x0A, 0x00, 0x09, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0xC8, 0xC8, 0xC8, 0x28, 0x02, 0x00, 0x01, 0x00, 0x03, 0x00, 0x09, 0x00, 0x0B, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28, 0x03, 0x00, 0x03, 0x00, 0x04, 0x00, 0x0B, 0x00,
		0x0C, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28, 0x04, 0x00, 0x04, 0x00,
		0x05, 0x00, 0x0C, 0x00, 0x0D, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28,
		0x05, 0x00, 0x05, 0x00, 0x06, 0x00, 0x0D, 0x00, 0x0E, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0xC8, 0xC8, 0xC8, 0x28, 0x06, 0x00, 0x06, 0x00, 0x07, 0x00, 0x0E, 0x00, 0x0F, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28, 0x07, 0x00, 0x07, 0x00, 0x08, 0x00, 0x0F, 0x00,
		0x10, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28, 0x08, 0x00, 0x08, 0x00,
		0x02, 0x00, 0x10, 0x00, 0x0A, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28,
		0x00, 0x00, 0x11, 0x00, 0x12, 0x00, 0x13, 0x00, 0x13, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0xC8, 0xC8, 0xC8, 0x28, 0x00, 0x00, 0x11, 0x00, 0x14, 0x00, 0x12, 0x00, 0x12, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28, 0x00, 0x00, 0x11, 0x00, 0x15, 0x00, 0x14, 0x00,
		0x14, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28, 0x00, 0x00, 0x11, 0x00,
		0x16, 0x00, 0x15, 0x00, 0x15, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28,
		0x00, 0x00, 0x11, 0x00, 0x17, 0x00, 0x16, 0x00, 0x16, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0xC8, 0xC8, 0xC8, 0x28, 0x00, 0x00, 0x11, 0x00, 0x18, 0x00, 0x17, 0x00, 0x17, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28, 0x00, 0x00, 0x11, 0x00, 0x19, 0x00, 0x18, 0x00,
		0x18, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28, 0x00, 0x00, 0x11, 0x00,
		0x13, 0x00, 0x19, 0x00, 0x19, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28,
		0x09, 0x00, 0x13, 0x00, 0x12, 0x00, 0x1B, 0x00, 0x1A, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0xC8, 0xC8, 0xC8, 0x28, 0x0A, 0x00, 0x12, 0x00, 0x14, 0x00, 0x1A, 0x00, 0x1C, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28, 0x0B, 0x00, 0x14, 0x00, 0x15, 0x00, 0x1C, 0x00,
		0x1D, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28, 0x0C, 0x00, 0x15, 0x00,
		0x16, 0x00, 0x1D, 0x00, 0x1E, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28,
		0x0D, 0x00, 0x16, 0x00, 0x17, 0x00, 0x1E, 0x00, 0x1F, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0xC8, 0xC8, 0xC8, 0x28, 0x0E, 0x00, 0x17, 0x00, 0x18, 0x00, 0x1F, 0x00, 0x20, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28, 0x0F, 0x00, 0x18, 0x00, 0x19, 0x00, 0x20, 0x00,
		0x21, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28, 0x10, 0x00, 0x19, 0x00,
		0x13, 0x00, 0x21, 0x00, 0x1B, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28,
		0x11, 0x00, 0x22, 0x00, 0x23, 0x00, 0x24, 0x00, 0x24, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0xC8, 0xC8, 0xC8, 0x28, 0x11, 0x00, 0x22, 0x00, 0x25, 0x00, 0x23, 0x00, 0x23, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28, 0x11, 0x00, 0x22, 0x00, 0x26, 0x00, 0x25, 0x00,
		0x25, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28, 0x11, 0x00, 0x22, 0x00,
		0x27, 0x00, 0x26, 0x00, 0x26, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28,
		0x11, 0x00, 0x22, 0x00, 0x28, 0x00, 0x27, 0x00, 0x27, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0xC8, 0xC8, 0xC8, 0x28, 0x11, 0x00, 0x22, 0x00, 0x29, 0x00, 0x28, 0x00, 0x28, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28, 0x11, 0x00, 0x22, 0x00, 0x2A, 0x00, 0x29, 0x00,
		0x29, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28, 0x11, 0x00, 0x22, 0x00,
		0x24, 0x00, 0x2A, 0x00, 0x2A, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28,
		0x12, 0x00, 0x24, 0x00, 0x23, 0x00, 0x2C, 0x00, 0x2B, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0xC8, 0xC8, 0xC8, 0x28, 0x13, 0x00, 0x23, 0x00, 0x25, 0x00, 0x2B, 0x00, 0x2D, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28, 0x02, 0x00, 0x25, 0x00, 0x26, 0x00, 0x2D, 0x00,
		0x2E, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28, 0x14, 0x00, 0x26, 0x00,
		0x27, 0x00, 0x2E, 0x00, 0x2F, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28,
		0x15, 0x00, 0x27, 0x00, 0x28, 0x00, 0x2F, 0x00, 0x30, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0xC8, 0xC8, 0xC8, 0x28, 0x07, 0x00, 0x28, 0x00, 0x29, 0x00, 0x30, 0x00, 0x31, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28, 0x06, 0x00, 0x29, 0x00, 0x2A, 0x00, 0x31, 0x00,
		0x32, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28, 0x16, 0x00, 0x2A, 0x00,
		0x24, 0x00, 0x32, 0x00, 0x2C, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28,
		0x11, 0x00, 0x33, 0x00, 0x34, 0x00, 0x35, 0x00, 0x35, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0xC8, 0xC8, 0xC8, 0x28, 0x11, 0x00, 0x33, 0x00, 0x36, 0x00, 0x34, 0x00, 0x34, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28, 0x11, 0x00, 0x33, 0x00, 0x37, 0x00, 0x36, 0x00,
		0x36, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28, 0x11, 0x00, 0x33, 0x00,
		0x38, 0x00, 0x37, 0x00, 0x37, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28,
		0x11, 0x00, 0x33, 0x00, 0x39, 0x00, 0x38, 0x00, 0x38, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0xC8, 0xC8, 0xC8, 0x28, 0x11, 0x00, 0x33, 0x00, 0x3A, 0x00, 0x39, 0x00, 0x39, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28, 0x11, 0x00, 0x33, 0x00, 0x3B, 0x00, 0x3A, 0x00,
		0x3A, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28, 0x11, 0x00, 0x33, 0x00,
		0x35, 0x00, 0x3B, 0x00, 0x3B, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28,
		0x17, 0x00, 0x35, 0x00, 0x34, 0x00, 0x3D, 0x00, 0x3C, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0xC8, 0xC8, 0xC8, 0x28, 0x18, 0x00, 0x34, 0x00, 0x36, 0x00, 0x3C, 0x00, 0x3E, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28, 0x19, 0x00, 0x36, 0x00, 0x37, 0x00, 0x3E, 0x00,
		0x3F, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28, 0x1A, 0x00, 0x37, 0x00,
		0x38, 0x00, 0x3F, 0x00, 0x40, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28,
		0x1B, 0x00, 0x38, 0x00, 0x39, 0x00, 0x40, 0x00, 0x41, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0xC8, 0xC8, 0xC8, 0x28, 0x1C, 0x00, 0x39, 0x00, 0x3A, 0x00, 0x41, 0x00, 0x42, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28, 0x0E, 0x00, 0x3A, 0x00, 0x3B, 0x00, 0x42, 0x00,
		0x43, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28, 0x1D, 0x00, 0x3B, 0x00,
		0x35, 0x00, 0x43, 0x00, 0x3D, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28,
		0x1E, 0x00, 0x44, 0x00, 0x45, 0x00, 0x47, 0x00, 0x46, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0xC8, 0xC8, 0xC8, 0x28, 0x1F, 0x00, 0x47, 0x00, 0x46, 0x00, 0x48, 0x00, 0x48, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28, 0x20, 0x00, 0x48, 0x00, 0x46, 0x00, 0x4A, 0x00,
		0x49, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28, 0x21, 0x00, 0x4B, 0x00,
		0x4C, 0x00, 0x4E, 0x00, 0x4D, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28,
		0x22, 0x00, 0x4D, 0x00, 0x4C, 0x00, 0x50, 0x00, 0x4F, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0xC8, 0xC8, 0xC8, 0x28, 0x23, 0x00, 0x45, 0x00, 0x44, 0x00, 0x51, 0x00, 0x51, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28, 0x24, 0x00, 0x52, 0x00, 0x45, 0x00, 0x53, 0x00,
		0x51, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28, 0x25, 0x00, 0x54, 0x00,
		0x55, 0x00, 0x57, 0x00, 0x56, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28,
		0x21, 0x00, 0x58, 0x00, 0x57, 0x00, 0x59, 0x00, 0x56, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0xC8, 0xC8, 0xC8, 0x28, 0x21, 0x00, 0x45, 0x00, 0x5A, 0x00, 0x46, 0x00, 0x5B, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28, 0x26, 0x00, 0x5C, 0x00, 0x5B, 0x00, 0x5D, 0x00,
		0x5D, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28, 0x26, 0x00, 0x5E, 0x00,
		0x5F, 0x00, 0x5A, 0x00, 0x5A, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28,
		0x21, 0x00, 0x5D, 0x00, 0x5B, 0x00, 0x5F, 0x00, 0x5A, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0xC8, 0xC8, 0xC8, 0x28, 0x21, 0x00, 0x5F, 0x00, 0x60, 0x00, 0x5D, 0x00, 0x61, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28, 0x26, 0x00, 0x62, 0x00, 0x63, 0x00, 0x61, 0x00,
		0x61, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28, 0x26, 0x00, 0x64, 0x00,
		0x60, 0x00, 0x65, 0x00, 0x65, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28,
		0x21, 0x00, 0x61, 0x00, 0x60, 0x00, 0x62, 0x00, 0x64, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0xC8, 0xC8, 0xC8, 0x28, 0x21, 0x00, 0x64, 0x00, 0x56, 0x00, 0x62, 0x00, 0x4C, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28, 0x27, 0x00, 0x56, 0x00, 0x55, 0x00, 0x4C, 0x00,
		0x4F, 0x00, 0x00, 0x00, 0x09, 0x07, 0x00, 0x2C, 0x00, 0x00, 0x18, 0x08, 0x3F, 0x00, 0x06, 0x00,
		0x00, 0x1F, 0x00, 0x00, 0x3F, 0x1F, 0x00, 0x00, 0x28, 0x00, 0x66, 0x00, 0x67, 0x00, 0x47, 0x00,
		0x44, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0x29, 0x00, 0x68, 0x00,
		0x69, 0x00, 0x66, 0x00, 0x67, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28,
		0x2A, 0x00, 0x6A, 0x00, 0x6B, 0x00, 0x68, 0x00, 0x69, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0xFF, 0x00, 0x00, 0x28, 0x2B, 0x00, 0x6C, 0x00, 0x6D, 0x00, 0x6A, 0x00, 0x6B, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0x2C, 0x00, 0x6E, 0x00, 0x6F, 0x00, 0x6C, 0x00,
		0x6D, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0x2D, 0x00, 0x70, 0x00,
		0x71, 0x00, 0x72, 0x00, 0x72, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28,
		0x2E, 0x00, 0x73, 0x00, 0x74, 0x00, 0x76, 0x00, 0x75, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0xFF, 0x00, 0x00, 0x28, 0x2F, 0x00, 0x77, 0x00, 0x78, 0x00, 0x73, 0x00, 0x74, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0x30, 0x00, 0x79, 0x00, 0x7A, 0x00, 0x77, 0x00,
		0x78, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0x31, 0x00, 0x71, 0x00,
		0x70, 0x00, 0x7B, 0x00, 0x7B, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28,
		0x32, 0x00, 0x7C, 0x00, 0x7D, 0x00, 0x7F, 0x00, 0x7E, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0xFF, 0x00, 0x00, 0x28, 0x33, 0x00, 0x80, 0x00, 0x81, 0x00, 0x7C, 0x00, 0x7D, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0x34, 0x00, 0x82, 0x00, 0x83, 0x00, 0x80, 0x00,
		0x81, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0x35, 0x00, 0x84, 0x00,
		0x85, 0x00, 0x82, 0x00, 0x83, 0x00, 0x00, 0x00, 0x09, 0x07, 0x00, 0x2C, 0x3F, 0x1F, 0x18, 0x08,
		0x00, 0x1F, 0x06, 0x00, 0x3F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x36, 0x00, 0x4F, 0x00,
		0x55, 0x00, 0x84, 0x00, 0x85, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0x80, 0x80, 0x80, 0x28,
		0x37, 0x00, 0x44, 0x00, 0x67, 0x00, 0x51, 0x00, 0x86, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0x80, 0x80, 0x80, 0x28, 0x38, 0x00, 0x87, 0x00, 0x88, 0x00, 0x8A, 0x00, 0x89, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0x39, 0x00, 0x69, 0x00, 0x6B, 0x00, 0x8C, 0x00,
		0x8B, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0x3A, 0x00, 0x6B, 0x00,
		0x6D, 0x00, 0x8B, 0x00, 0x8D, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28,
		0x3B, 0x00, 0x6D, 0x00, 0x6F, 0x00, 0x8D, 0x00, 0x8E, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0xFF, 0x00, 0x00, 0x28, 0x3C, 0x00, 0x8F, 0x00, 0x90, 0x00, 0x91, 0x00, 0x91, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0x3D, 0x00, 0x75, 0x00, 0x74, 0x00, 0x93, 0x00,
		0x92, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0x3E, 0x00, 0x74, 0x00,
		0x78, 0x00, 0x92, 0x00, 0x94, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28,
		0x3F, 0x00, 0x78, 0x00, 0x7A, 0x00, 0x94, 0x00, 0x95, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0xFF, 0x00, 0x00, 0x28, 0x40, 0x00, 0x7B, 0x00, 0x70, 0x00, 0x97, 0x00, 0x96, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0x41, 0x00, 0x7E, 0x00, 0x7D, 0x00, 0x99, 0x00,
		0x98, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0x33, 0x00, 0x7D, 0x00,
		0x81, 0x00, 0x98, 0x00, 0x9A, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28,
		0x42, 0x00, 0x81, 0x00, 0x83, 0x00, 0x9A, 0x00, 0x9B, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0x80, 0x80, 0x80, 0x28, 0x43, 0x00, 0x4A, 0x00, 0x9C, 0x00, 0x9D, 0x00, 0x9D, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0x44, 0x00, 0x85, 0x00, 0x55, 0x00, 0x9E, 0x00,
		0x54, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0x45, 0x00, 0x8B, 0x00,
		0x9F, 0x00, 0x8C, 0x00, 0x8C, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28,
		0x46, 0x00, 0x8B, 0x00, 0x8D, 0x00, 0xA1, 0x00, 0xA0, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0x80, 0x80, 0x80, 0x28, 0x47, 0x00, 0x93, 0x00, 0x92, 0x00, 0xA3, 0x00, 0xA2, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0x48, 0x00, 0x95, 0x00, 0xA4, 0x00, 0x94, 0x00,
		0x94, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0x49, 0x00, 0xA5, 0x00,
		0x99, 0x00, 0xA6, 0x00, 0xA6, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28,
		0x4A, 0x00, 0x99, 0x00, 0x98, 0x00, 0xA6, 0x00, 0xA7, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0xFF, 0x00, 0x00, 0x28, 0x4B, 0x00, 0x98, 0x00, 0x9A, 0x00, 0xA7, 0x00, 0xA8, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0x4C, 0x00, 0x9A, 0x00, 0x9B, 0x00, 0xA8, 0x00,
		0xA9, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0x4D, 0x00, 0xAA, 0x00,
		0xAB, 0x00, 0xAC, 0x00, 0xAC, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28,
		0x4E, 0x00, 0x9E, 0x00, 0x54, 0x00, 0xAD, 0x00, 0x57, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0x80, 0x80, 0x80, 0x28, 0x4F, 0x00, 0xA3, 0x00, 0xA2, 0x00, 0xAF, 0x00, 0xAE, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0xFF, 0xFF, 0xFF, 0x28, 0x50, 0x00, 0xA4, 0x00, 0xA5, 0x00, 0xB1, 0x00,
		0xB0, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28, 0x51, 0x00, 0xA5, 0x00,
		0xA6, 0x00, 0xB0, 0x00, 0xB2, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28,
		0x52, 0x00, 0xA6, 0x00, 0xA7, 0x00, 0xB2, 0x00, 0xB3, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0xFF, 0x00, 0x00, 0x28, 0x53, 0x00, 0xA7, 0x00, 0xA8, 0x00, 0xB3, 0x00, 0xB4, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0x54, 0x00, 0xA8, 0x00, 0xA9, 0x00, 0xB4, 0x00,
		0xB5, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0x55, 0x00, 0xA9, 0x00,
		0xAD, 0x00, 0xB5, 0x00, 0xB6, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28,
		0x56, 0x00, 0xB3, 0x00, 0xB7, 0x00, 0xB2, 0x00, 0xB2, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0xFF, 0x00, 0x00, 0x28, 0x57, 0x00, 0xB4, 0x00, 0xB8, 0x00, 0xB3, 0x00, 0xB3, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0x58, 0x00, 0xB5, 0x00, 0xB9, 0x00, 0xB4, 0x00,
		0xB4, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0x59, 0x00, 0xB6, 0x00,
		0x59, 0x00, 0xB5, 0x00, 0xB5, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28,
		0x5A, 0x00, 0xA1, 0x00, 0xA0, 0x00, 0xBA, 0x00, 0xBA, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0xFF, 0x00, 0x00, 0x28, 0x5B, 0x00, 0xA1, 0x00, 0xBA, 0x00, 0xBB, 0x00, 0xBB, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0x5C, 0x00, 0x9F, 0x00, 0xBB, 0x00, 0xBC, 0x00,
		0xBC, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0x5D, 0x00, 0x9F, 0x00,
		0xA1, 0x00, 0xBB, 0x00, 0xBB, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0x80, 0x80, 0x80, 0x28,
		0x5E, 0x00, 0x8E, 0x00, 0x93, 0x00, 0xAF, 0x00, 0xA3, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0xFF, 0x00, 0x00, 0x28, 0x5F, 0x00, 0xA0, 0x00, 0x8D, 0x00, 0xAF, 0x00, 0x8E, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0x60, 0x00, 0x97, 0x00, 0x96, 0x00, 0x5D, 0x00,
		0x5C, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0x80, 0x80, 0x80, 0x28, 0x61, 0x00, 0x86, 0x00,
		0x53, 0x00, 0x51, 0x00, 0x51, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28,
		0x62, 0x00, 0x58, 0x00, 0xB6, 0x00, 0x57, 0x00, 0xAD, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0xFF, 0x00, 0x00, 0x28, 0x63, 0x00, 0x95, 0x00, 0xA5, 0x00, 0xA4, 0x00, 0xA4, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0x64, 0x00, 0xBC, 0x00, 0xBB, 0x00, 0xBD, 0x00,
		0xBD, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28, 0x11, 0x00, 0xBE, 0x00,
		0x65, 0x00, 0xBF, 0x00, 0xBF, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28,
		0x11, 0x00, 0xC0, 0x00, 0x5E, 0x00, 0xC1, 0x00, 0xC1, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0xFF, 0x00, 0x00, 0x28, 0x65, 0x00, 0x53, 0x00, 0xBC, 0x00, 0x52, 0x00, 0xBD, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0x11, 0x00, 0xC0, 0x00, 0xC1, 0x00, 0xC2, 0x00,
		0xC2, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28, 0x11, 0x00, 0xC3, 0x00,
		0xBE, 0x00, 0xBF, 0x00, 0xBF, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28,
		0x11, 0x00, 0xB7, 0x00, 0xC3, 0x00, 0xC4, 0x00, 0xC4, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0xFF, 0x00, 0x00, 0x28, 0x66, 0x00, 0xB0, 0x00, 0xB7, 0x00, 0xC4, 0x00, 0xC4, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0x67, 0x00, 0xC5, 0x00, 0xB1, 0x00, 0xC4, 0x00,
		0xB0, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0x68, 0x00, 0xC4, 0x00,
		0xC3, 0x00, 0xC5, 0x00, 0xBF, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28,
		0x69, 0x00, 0xAF, 0x00, 0xC6, 0x00, 0xC7, 0x00, 0xC7, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0xFF, 0x00, 0x00, 0x28, 0x6A, 0x00, 0xC6, 0x00, 0xC0, 0x00, 0xC7, 0x00, 0xC2, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0x6B, 0x00, 0xB3, 0x00, 0xB8, 0x00, 0xB7, 0x00,
		0xB7, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0x6C, 0x00, 0xB4, 0x00,
		0xB9, 0x00, 0xB8, 0x00, 0xB8, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28,
		0x6D, 0x00, 0xB6, 0x00, 0x58, 0x00, 0x59, 0x00, 0x59, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0xFF, 0x00, 0x00, 0x28, 0x6E, 0x00, 0xB5, 0x00, 0x59, 0x00, 0xB9, 0x00, 0xB9, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0x6F, 0x00, 0xAF, 0x00, 0xAE, 0x00, 0xC6, 0x00,
		0xC6, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0x70, 0x00, 0x8B, 0x00,
		0xA1, 0x00, 0x9F, 0x00, 0x9F, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28,
		0x11, 0x00, 0xC7, 0x00, 0xC2, 0x00, 0xBA, 0x00, 0xBA, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0xFF, 0x00, 0x00, 0x28, 0x71, 0x00, 0xBA, 0x00, 0xAF, 0x00, 0xC7, 0x00, 0xC7, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0x72, 0x00, 0xBA, 0x00, 0xA0, 0x00, 0xAF, 0x00,
		0xAF, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0x80, 0x80, 0x80, 0x28, 0x73, 0x00, 0x86, 0x00,
		0xBC, 0x00, 0x53, 0x00, 0x53, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28,
		0x74, 0x00, 0xB0, 0x00, 0xB2, 0x00, 0xB7, 0x00, 0xB7, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0xFF, 0x00, 0x00, 0x28, 0x75, 0x00, 0xC8, 0x00, 0xC6, 0x00, 0xAE, 0x00, 0xAE, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0x76, 0x00, 0xC9, 0x00, 0xC0, 0x00, 0xC8, 0x00,
		0xC6, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0x77, 0x00, 0x5F, 0x00,
		0x5E, 0x00, 0xC9, 0x00, 0xC0, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28,
		0x78, 0x00, 0x94, 0x00, 0xA4, 0x00, 0xCA, 0x00, 0xCA, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0x80, 0x80, 0x80, 0x28, 0x79, 0x00, 0xCA, 0x00, 0xA4, 0x00, 0xCB, 0x00, 0xB1, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0x7A, 0x00, 0xCB, 0x00, 0xB1, 0x00, 0xCC, 0x00,
		0xC5, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0x7B, 0x00, 0xCC, 0x00,
		0xC5, 0x00, 0xCD, 0x00, 0xBF, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28,
		0x7C, 0x00, 0xCE, 0x00, 0xCF, 0x00, 0xD1, 0x00, 0xD0, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0xFF, 0x00, 0x00, 0x28, 0x77, 0x00, 0xCD, 0x00, 0xBF, 0x00, 0x60, 0x00, 0x65, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0x7D, 0x00, 0xD2, 0x00, 0xD3, 0x00, 0xCE, 0x00,
		0xCF, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0x7E, 0x00, 0xD4, 0x00,
		0xCB, 0x00, 0xCC, 0x00, 0xCC, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28,
		0x7F, 0x00, 0xCE, 0x00, 0xD1, 0x00, 0xD5, 0x00, 0xD5, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0xFF, 0x00, 0x00, 0x28, 0x60, 0x00, 0x61, 0x00, 0x63, 0x00, 0xD2, 0x00, 0xD3, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0x80, 0x80, 0x80, 0x28, 0x80, 0x00, 0xD6, 0x00, 0xCA, 0x00, 0xD4, 0x00,
		0xCB, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0x80, 0x80, 0x80, 0x28, 0x81, 0x00, 0xD6, 0x00,
		0xA2, 0x00, 0x92, 0x00, 0x92, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0x80, 0x80, 0x80, 0x28,
		0x82, 0x00, 0x92, 0x00, 0x94, 0x00, 0xD6, 0x00, 0xCA, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0x80, 0x80, 0x80, 0x28, 0x83, 0x00, 0x88, 0x00, 0xD7, 0x00, 0x89, 0x00, 0x89, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0x80, 0x80, 0x80, 0x28, 0x84, 0x00, 0x48, 0x00, 0x9D, 0x00, 0x47, 0x00,
		0x66, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0x80, 0x80, 0x80, 0x28, 0x85, 0x00, 0xD5, 0x00,
		0xD1, 0x00, 0x87, 0x00, 0x88, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28,
		0x86, 0x00, 0xD8, 0x00, 0x91, 0x00, 0x68, 0x00, 0x6A, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0xFF, 0x00, 0x00, 0x28, 0x87, 0x00, 0x91, 0x00, 0xD9, 0x00, 0x6A, 0x00, 0x6C, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0x88, 0x00, 0xD9, 0x00, 0xDA, 0x00, 0x6C, 0x00,
		0x6E, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0x00, 0x00, 0xDB, 0x00,
		0xDC, 0x00, 0xDD, 0x00, 0xDD, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28,
		0x89, 0x00, 0xDE, 0x00, 0x8A, 0x00, 0x76, 0x00, 0x73, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0xFF, 0x00, 0x00, 0x28, 0x8A, 0x00, 0x8A, 0x00, 0x89, 0x00, 0x73, 0x00, 0x77, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0x8B, 0x00, 0x89, 0x00, 0xDF, 0x00, 0x77, 0x00,
		0x79, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0x80, 0x80, 0x80, 0x28, 0x8C, 0x00, 0xD1, 0x00,
		0xD0, 0x00, 0x88, 0x00, 0xD7, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28,
		0x8D, 0x00, 0xE0, 0x00, 0xE1, 0x00, 0x7F, 0x00, 0x7C, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0xFF, 0x00, 0x00, 0x28, 0x33, 0x00, 0xE1, 0x00, 0xE2, 0x00, 0x7C, 0x00, 0x80, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0x42, 0x00, 0xE2, 0x00, 0xE3, 0x00, 0x80, 0x00,
		0x82, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0x8E, 0x00, 0xDD, 0x00,
		0x72, 0x00, 0xDB, 0x00, 0xDB, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28,
		0x8F, 0x00, 0xE4, 0x00, 0x50, 0x00, 0x84, 0x00, 0x4F, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0xFF, 0x00, 0x00, 0x28, 0x90, 0x00, 0xD8, 0x00, 0x8F, 0x00, 0x91, 0x00, 0x91, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0x91, 0x00, 0x90, 0x00, 0xE5, 0x00, 0x91, 0x00,
		0xD9, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0x80, 0x80, 0x80, 0x28, 0x92, 0x00, 0xE6, 0x00,
		0xE7, 0x00, 0xDE, 0x00, 0x8A, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28,
		0x93, 0x00, 0x89, 0x00, 0xD7, 0x00, 0xDF, 0x00, 0xDF, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0xFF, 0x00, 0x00, 0x28, 0x94, 0x00, 0xE8, 0x00, 0xE0, 0x00, 0xE9, 0x00, 0xE9, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0x95, 0x00, 0xE8, 0x00, 0xEA, 0x00, 0xE0, 0x00,
		0xE1, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0x96, 0x00, 0xEA, 0x00,
		0xEB, 0x00, 0xE1, 0x00, 0xE2, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28,
		0x97, 0x00, 0xEB, 0x00, 0xEC, 0x00, 0xE2, 0x00, 0xE3, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0xFF, 0x00, 0x00, 0x28, 0x98, 0x00, 0x72, 0x00, 0xE5, 0x00, 0xDB, 0x00, 0xDB, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0x99, 0x00, 0xED, 0x00, 0x4D, 0x00, 0xE4, 0x00,
		0x50, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0x80, 0x80, 0x80, 0x28, 0x9A, 0x00, 0x72, 0x00,
		0x71, 0x00, 0xE6, 0x00, 0xE7, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28,
		0x9B, 0x00, 0xD0, 0x00, 0xAC, 0x00, 0xD7, 0x00, 0xE9, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0xC8, 0xC8, 0xC8, 0x28, 0x9C, 0x00, 0xAC, 0x00, 0xAB, 0x00, 0xE9, 0x00, 0xE8, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0x9D, 0x00, 0xAB, 0x00, 0xEE, 0x00, 0xE8, 0x00,
		0xEA, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0x9E, 0x00, 0xEE, 0x00,
		0xEF, 0x00, 0xEA, 0x00, 0xEB, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28,
		0x9F, 0x00, 0xEF, 0x00, 0xF0, 0x00, 0xEB, 0x00, 0xEC, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0xFF, 0x00, 0x00, 0x28, 0xA0, 0x00, 0xF0, 0x00, 0xF1, 0x00, 0xEC, 0x00, 0xED, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0xA1, 0x00, 0xAB, 0x00, 0xAA, 0x00, 0xEE, 0x00,
		0xEE, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0xA2, 0x00, 0xEE, 0x00,
		0xF2, 0x00, 0xEF, 0x00, 0xEF, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28,
		0xA3, 0x00, 0xEF, 0x00, 0xF3, 0x00, 0xF0, 0x00, 0xF0, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0xFF, 0x00, 0x00, 0x28, 0xA4, 0x00, 0xF0, 0x00, 0x4B, 0x00, 0xF1, 0x00, 0xF1, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0xA5, 0x00, 0xDB, 0x00, 0xE5, 0x00, 0x90, 0x00,
		0x90, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0xA6, 0x00, 0xF4, 0x00,
		0xDB, 0x00, 0x90, 0x00, 0x90, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28,
		0xA7, 0x00, 0x9C, 0x00, 0xF4, 0x00, 0x8F, 0x00, 0x8F, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0xFF, 0x00, 0x00, 0x28, 0xA8, 0x00, 0xF4, 0x00, 0x90, 0x00, 0x8F, 0x00, 0x8F, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0x80, 0x80, 0x80, 0x28, 0xA9, 0x00, 0x72, 0x00, 0xE6, 0x00, 0xDA, 0x00,
		0xDE, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0xAA, 0x00, 0x72, 0x00,
		0xDA, 0x00, 0xE5, 0x00, 0xD9, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0x80, 0x80, 0x80, 0x28,
		0x83, 0x00, 0x8A, 0x00, 0xE7, 0x00, 0x87, 0x00, 0x87, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0x80, 0x80, 0x80, 0x28, 0xAB, 0x00, 0x48, 0x00, 0x4A, 0x00, 0x9D, 0x00, 0x9D, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0xAC, 0x00, 0x4D, 0x00, 0xED, 0x00, 0x4E, 0x00,
		0xF1, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0xAD, 0x00, 0xD7, 0x00,
		0xE9, 0x00, 0xDF, 0x00, 0xDF, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28,
		0xAE, 0x00, 0xF5, 0x00, 0xF4, 0x00, 0x9C, 0x00, 0x9C, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0xC8, 0xC8, 0xC8, 0x28, 0x00, 0x00, 0xD3, 0x00, 0x63, 0x00, 0xF6, 0x00, 0xF6, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0x00, 0x00, 0xF7, 0x00, 0x5C, 0x00, 0x96, 0x00,
		0x96, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0xAF, 0x00, 0x49, 0x00,
		0xF5, 0x00, 0x4A, 0x00, 0x9C, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28,
		0x00, 0x00, 0xDC, 0x00, 0xF7, 0x00, 0x96, 0x00, 0x96, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0xC8, 0xC8, 0xC8, 0x28, 0x00, 0x00, 0xD3, 0x00, 0xF6, 0x00, 0xF8, 0x00, 0xF8, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0x00, 0x00, 0xF9, 0x00, 0xF8, 0x00, 0xAA, 0x00,
		0xAA, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0xB0, 0x00, 0xF9, 0x00,
		0xAA, 0x00, 0xAC, 0x00, 0xAC, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28,
		0xB1, 0x00, 0xF9, 0x00, 0xAC, 0x00, 0xCF, 0x00, 0xD0, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0xFF, 0x00, 0x00, 0x28, 0xB2, 0x00, 0xCF, 0x00, 0xD3, 0x00, 0xF9, 0x00, 0xF8, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0xB3, 0x00, 0xDD, 0x00, 0x70, 0x00, 0x72, 0x00,
		0x72, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0xB4, 0x00, 0xDD, 0x00,
		0xDC, 0x00, 0x70, 0x00, 0x96, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28,
		0xB5, 0x00, 0xAA, 0x00, 0xF2, 0x00, 0xEE, 0x00, 0xEE, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0xFF, 0x00, 0x00, 0x28, 0xB6, 0x00, 0xF2, 0x00, 0xF3, 0x00, 0xEF, 0x00, 0xEF, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0xB7, 0x00, 0x4B, 0x00, 0x4E, 0x00, 0xF1, 0x00,
		0xF1, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0xB8, 0x00, 0xF3, 0x00,
		0x4B, 0x00, 0xF0, 0x00, 0xF0, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0xFF, 0xFF, 0x28,
		0xB9, 0x00, 0x76, 0x00, 0x75, 0x00, 0x6E, 0x00, 0x6F, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0xFF, 0xFF, 0xFF, 0x28, 0xBA, 0x00, 0x6F, 0x00, 0x75, 0x00, 0x8E, 0x00, 0x93, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0xFF, 0xFF, 0xFF, 0x28, 0xBB, 0x00, 0xDA, 0x00, 0xDE, 0x00, 0x6E, 0x00,
		0x76, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28, 0xBC, 0x00, 0x83, 0x00,
		0x85, 0x00, 0x9B, 0x00, 0x9E, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28,
		0xBD, 0x00, 0x9B, 0x00, 0x9E, 0x00, 0xA9, 0x00, 0xAD, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0xC8, 0xC8, 0xC8, 0x28, 0xBE, 0x00, 0xE3, 0x00, 0xE4, 0x00, 0x82, 0x00, 0x84, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0xBF, 0x00, 0xEC, 0x00, 0xED, 0x00, 0xE3, 0x00,
		0xE4, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xC8, 0xC8, 0xC8, 0x28, 0xC0, 0x00, 0x9D, 0x00,
		0xD8, 0x00, 0x66, 0x00, 0x68, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28,
		0xC1, 0x00, 0x9C, 0x00, 0x8F, 0x00, 0x9D, 0x00, 0xD8, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0xC8, 0xC8, 0xC8, 0x28, 0xC2, 0x00, 0x67, 0x00, 0x69, 0x00, 0x86, 0x00, 0x8C, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0xC3, 0x00, 0x86, 0x00, 0x8C, 0x00, 0xBC, 0x00,
		0x9F, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0xFF, 0xFF, 0x28, 0xC4, 0x00, 0x7F, 0x00,
		0x7E, 0x00, 0x79, 0x00, 0x7A, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0xFF, 0xFF, 0x28,
		0xC5, 0x00, 0x7A, 0x00, 0x7E, 0x00, 0x95, 0x00, 0x99, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0xFF, 0x00, 0x00, 0x28, 0xC6, 0x00, 0xE0, 0x00, 0xDF, 0x00, 0xE9, 0x00, 0xE9, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0xC7, 0x00, 0xA5, 0x00, 0x95, 0x00, 0x99, 0x00,
		0x99, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0xFF, 0xFF, 0x28, 0xC8, 0x00, 0xDF, 0x00,
		0xE0, 0x00, 0x79, 0x00, 0x7F, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0xFF, 0xFF, 0x28,
		0xC9, 0x00, 0x87, 0x00, 0xE7, 0x00, 0xD5, 0x00, 0x71, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0xFF, 0x00, 0x00, 0x28, 0xCA, 0x00, 0xCE, 0x00, 0x7B, 0x00, 0xD2, 0x00, 0x97, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0x60, 0x00, 0xD2, 0x00, 0x97, 0x00, 0x61, 0x00,
		0x5D, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0xCB, 0x00, 0xD5, 0x00,
		0x71, 0x00, 0xCE, 0x00, 0x7B, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28,
		0xCC, 0x00, 0xCD, 0x00, 0xC9, 0x00, 0xCC, 0x00, 0xC8, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28,
		0xFF, 0x00, 0x00, 0x28, 0x77, 0x00, 0x60, 0x00, 0x5F, 0x00, 0xCD, 0x00, 0xC9, 0x00, 0x00, 0x00,
		0x05, 0x04, 0x00, 0x28, 0xFF, 0x00, 0x00, 0x28, 0xCD, 0x00, 0xCC, 0x00, 0xC8, 0x00, 0xD4, 0x00,
		0xAE, 0x00, 0x00, 0x00, 0x05, 0x04, 0x00, 0x28, 0xFF, 0xFF, 0xFF, 0x28, 0xCE, 0x00, 0xD4, 0x00,
		0xAE, 0x00, 0xD6, 0x00, 0xA2, 0x00, 0x00, 0x00, 0xC4, 0x00, 0x51, 0x00, 0x45, 0x01, 0x00, 0x00,
		0xC4, 0x00, 0x1B, 0x00, 0x7B, 0x01, 0x00, 0x00, 0xC4, 0x00, 0x51, 0x00, 0x91, 0x01, 0x00, 0x00,
		0xC4, 0x00, 0x04, 0x00, 0x45, 0x01, 0x00, 0x00, 0xC4, 0x00, 0x1B, 0x00, 0x0E, 0x01, 0x00, 0x00,
		0xC4, 0x00, 0x51, 0x00, 0xF8, 0x00, 0x00, 0x00, 0xC4, 0x00, 0x87, 0x00, 0x0E, 0x01, 0x00, 0x00,
		0xC4, 0x00, 0x9D, 0x00, 0x45, 0x01, 0x00, 0x00, 0xC4, 0x00, 0x87, 0x00, 0x7B, 0x01, 0x00, 0x00,
		0x8B, 0x00, 0x1B, 0x00, 0x7B, 0x01, 0x00, 0x00, 0x8B, 0x00, 0x51, 0x00, 0x91, 0x01, 0x00, 0x00,
		0x8B, 0x00, 0x04, 0x00, 0x45, 0x01, 0x00, 0x00, 0x8B, 0x00, 0x1B, 0x00, 0x0E, 0x01, 0x00, 0x00,
		0x8B, 0x00, 0x51, 0x00, 0xF8, 0x00, 0x00, 0x00, 0x8B, 0x00, 0x87, 0x00, 0x0E, 0x01, 0x00, 0x00,
		0x8B, 0x00, 0x9D, 0x00, 0x45, 0x01, 0x00, 0x00, 0x8B, 0x00, 0x87, 0x00, 0x7B, 0x01, 0x00, 0x00,
		0xC8, 0x00, 0x51, 0x00, 0xCE, 0xFE, 0x00, 0x00, 0xC8, 0x00, 0x1B, 0x00, 0x04, 0xFF, 0x00, 0x00,
		0xC8, 0x00, 0x51, 0x00, 0x1A, 0xFF, 0x00, 0x00, 0xC8, 0x00, 0x04, 0x00, 0xCE, 0xFE, 0x00, 0x00,
		0xC8, 0x00, 0x1B, 0x00, 0x98, 0xFE, 0x00, 0x00, 0xC8, 0x00, 0x51, 0x00, 0x81, 0xFE, 0x00, 0x00,
		0xC8, 0x00, 0x87, 0x00, 0x98, 0xFE, 0x00, 0x00, 0xC8, 0x00, 0x9D, 0x00, 0xCE, 0xFE, 0x00, 0x00,
		0xC8, 0x00, 0x87, 0x00, 0x04, 0xFF, 0x00, 0x00, 0x8E, 0x00, 0x1B, 0x00, 0x04, 0xFF, 0x00, 0x00,
		0x8E, 0x00, 0x51, 0x00, 0x1A, 0xFF, 0x00, 0x00, 0x8E, 0x00, 0x04, 0x00, 0xCE, 0xFE, 0x00, 0x00,
		0x8E, 0x00, 0x1B, 0x00, 0x98, 0xFE, 0x00, 0x00, 0x8E, 0x00, 0x51, 0x00, 0x81, 0xFE, 0x00, 0x00,
		0x8E, 0x00, 0x87, 0x00, 0x98, 0xFE, 0x00, 0x00, 0x8E, 0x00, 0x9D, 0x00, 0xCE, 0xFE, 0x00, 0x00,
		0x8E, 0x00, 0x87, 0x00, 0x04, 0xFF, 0x00, 0x00, 0x3C, 0xFF, 0x51, 0x00, 0x45, 0x01, 0x00, 0x00,
		0x3C, 0xFF, 0x1B, 0x00, 0x0E, 0x01, 0x00, 0x00, 0x3C, 0xFF, 0x51, 0x00, 0xF8, 0x00, 0x00, 0x00,
		0x3C, 0xFF, 0x04, 0x00, 0x45, 0x01, 0x00, 0x00, 0x3C, 0xFF, 0x1B, 0x00, 0x7B, 0x01, 0x00, 0x00,
		0x3C, 0xFF, 0x51, 0x00, 0x91, 0x01, 0x00, 0x00, 0x3C, 0xFF, 0x87, 0x00, 0x7B, 0x01, 0x00, 0x00,
		0x3C, 0xFF, 0x9D, 0x00, 0x45, 0x01, 0x00, 0x00, 0x3C, 0xFF, 0x87, 0x00, 0x0E, 0x01, 0x00, 0x00,
		0x75, 0xFF, 0x1B, 0x00, 0x0E, 0x01, 0x00, 0x00, 0x75, 0xFF, 0x51, 0x00, 0xF8, 0x00, 0x00, 0x00,
		0x75, 0xFF, 0x04, 0x00, 0x45, 0x01, 0x00, 0x00, 0x75, 0xFF, 0x1B, 0x00, 0x7B, 0x01, 0x00, 0x00,
		0x75, 0xFF, 0x51, 0x00, 0x91, 0x01, 0x00, 0x00, 0x75, 0xFF, 0x87, 0x00, 0x7B, 0x01, 0x00, 0x00,
		0x75, 0xFF, 0x9D, 0x00, 0x45, 0x01, 0x00, 0x00, 0x75, 0xFF, 0x87, 0x00, 0x0E, 0x01, 0x00, 0x00,
		0x38, 0xFF, 0x51, 0x00, 0xCE, 0xFE, 0x00, 0x00, 0x38, 0xFF, 0x1B, 0x00, 0x98, 0xFE, 0x00, 0x00,
		0x38, 0xFF, 0x51, 0x00, 0x81, 0xFE, 0x00, 0x00, 0x38, 0xFF, 0x04, 0x00, 0xCE, 0xFE, 0x00, 0x00,
		0x38, 0xFF, 0x1B, 0x00, 0x04, 0xFF, 0x00, 0x00, 0x38, 0xFF, 0x51, 0x00, 0x1A, 0xFF, 0x00, 0x00,
		0x38, 0xFF, 0x87, 0x00, 0x04, 0xFF, 0x00, 0x00, 0x38, 0xFF, 0x9D, 0x00, 0xCE, 0xFE, 0x00, 0x00,
		0x38, 0xFF, 0x87, 0x00, 0x98, 0xFE, 0x00, 0x00, 0x72, 0xFF, 0x1B, 0x00, 0x98, 0xFE, 0x00, 0x00,
		0x72, 0xFF, 0x51, 0x00, 0x81, 0xFE, 0x00, 0x00, 0x72, 0xFF, 0x04, 0x00, 0xCE, 0xFE, 0x00, 0x00,
		0x72, 0xFF, 0x1B, 0x00, 0x04, 0xFF, 0x00, 0x00, 0x72, 0xFF, 0x51, 0x00, 0x1A, 0xFF, 0x00, 0x00,
		0x72, 0xFF, 0x87, 0x00, 0x04, 0xFF, 0x00, 0x00, 0x72, 0xFF, 0x9D, 0x00, 0xCE, 0xFE, 0x00, 0x00,
		0x72, 0xFF, 0x87, 0x00, 0x98, 0xFE, 0x00, 0x00, 0xC8, 0xFF, 0x6F, 0x00, 0xF4, 0x01, 0x00, 0x00,
		0x96, 0xFF, 0x6F, 0x00, 0x92, 0x01, 0x00, 0x00, 0x6A, 0x00, 0x6F, 0x00, 0x92, 0x01, 0x00, 0x00,
		0x38, 0x00, 0x6F, 0x00, 0xF4, 0x01, 0x00, 0x00, 0x91, 0x00, 0x6F, 0x00, 0xE1, 0x01, 0x00, 0x00,
		0xCE, 0x00, 0x6F, 0x00, 0x91, 0x01, 0x00, 0x00, 0xC3, 0x00, 0x6F, 0x00, 0xB3, 0x01, 0x00, 0x00,
		0xCE, 0x00, 0x6F, 0x00, 0x7D, 0xFE, 0x00, 0x00, 0x6A, 0x00, 0x6F, 0x00, 0x7D, 0xFE, 0x00, 0x00,
		0xAC, 0x00, 0x6F, 0x00, 0x1E, 0xFE, 0x00, 0x00, 0xBF, 0x00, 0x6F, 0x00, 0x3C, 0xFE, 0x00, 0x00,
		0x38, 0x00, 0x6F, 0x00, 0x16, 0xFE, 0x00, 0x00, 0x86, 0x00, 0x6F, 0x00, 0x16, 0xFE, 0x00, 0x00,
		0x6F, 0xFF, 0x6F, 0x00, 0xE1, 0x01, 0x00, 0x00, 0x32, 0xFF, 0x6F, 0x00, 0x91, 0x01, 0x00, 0x00,
		0x3D, 0xFF, 0x6F, 0x00, 0xB3, 0x01, 0x00, 0x00, 0x7A, 0xFF, 0x6F, 0x00, 0x16, 0xFE, 0x00, 0x00,
		0xC8, 0xFF, 0x6F, 0x00, 0x16, 0xFE, 0x00, 0x00, 0x96, 0xFF, 0x6F, 0x00, 0x7D, 0xFE, 0x00, 0x00,
		0x54, 0xFF, 0x6F, 0x00, 0x1E, 0xFE, 0x00, 0x00, 0x41, 0xFF, 0x6F, 0x00, 0x3C, 0xFE, 0x00, 0x00,
		0x32, 0xFF, 0x6F, 0x00, 0x7D, 0xFE, 0x00, 0x00, 0x96, 0xFF, 0x6F, 0x00, 0xF6, 0x00, 0x00, 0x00,
		0x6A, 0x00, 0x6F, 0x00, 0xF6, 0x00, 0x00, 0x00, 0xCE, 0x00, 0x6F, 0x00, 0xF6, 0x00, 0x00, 0x00,
		0xCE, 0x00, 0x6F, 0x00, 0x5A, 0x00, 0x00, 0x00, 0x32, 0xFF, 0x6F, 0x00, 0xF6, 0x00, 0x00, 0x00,
		0x32, 0xFF, 0x6F, 0x00, 0x5A, 0x00, 0x00, 0x00, 0x32, 0xFF, 0x6F, 0x00, 0x42, 0xFF, 0x00, 0x00,
		0xCE, 0x00, 0x6F, 0x00, 0x42, 0xFF, 0x00, 0x00, 0x6A, 0x00, 0x6F, 0x00, 0x19, 0xFF, 0x00, 0x00,
		0xCE, 0x00, 0x6F, 0x00, 0x19, 0xFF, 0x00, 0x00, 0x96, 0xFF, 0x6F, 0x00, 0x19, 0xFF, 0x00, 0x00,
		0x32, 0xFF, 0x6F, 0x00, 0x19, 0xFF, 0x00, 0x00, 0x38, 0x00, 0x32, 0x00, 0xF0, 0x01, 0x00, 0x00,
		0xC8, 0xFF, 0x32, 0x00, 0xF0, 0x01, 0x00, 0x00, 0x44, 0x00, 0x0F, 0x00, 0xD6, 0x01, 0x00, 0x00,
		0xBC, 0xFF, 0x0F, 0x00, 0xD6, 0x01, 0x00, 0x00, 0x38, 0x00, 0xF5, 0xFF, 0xB4, 0x01, 0x00, 0x00,
		0xC8, 0xFF, 0xF5, 0xFF, 0xB4, 0x01, 0x00, 0x00, 0x38, 0x00, 0xD8, 0xFF, 0x6E, 0x01, 0x00, 0x00,
		0xC8, 0xFF, 0xD8, 0xFF, 0x6E, 0x01, 0x00, 0x00, 0x38, 0x00, 0xBE, 0xFF, 0x7E, 0x00, 0x00, 0x00,
		0xC8, 0xFF, 0xBE, 0xFF, 0x7E, 0x00, 0x00, 0x00, 0xCE, 0x00, 0x03, 0x00, 0x7A, 0x00, 0x00, 0x00,
		0xBF, 0x00, 0xC7, 0xFF, 0x52, 0x00, 0x00, 0x00, 0xBF, 0x00, 0xC7, 0xFF, 0x6B, 0x00, 0x00, 0x00,
		0x38, 0x00, 0x63, 0xFF, 0xDF, 0xFF, 0x00, 0x00, 0xC8, 0xFF, 0x63, 0xFF, 0xDF, 0xFF, 0x00, 0x00,
		0xC8, 0xFF, 0x71, 0xFF, 0xFE, 0xFF, 0x00, 0x00, 0x38, 0x00, 0x71, 0xFF, 0xFE, 0xFF, 0x00, 0x00,
		0x38, 0x00, 0x63, 0xFF, 0x33, 0xFF, 0x00, 0x00, 0xC8, 0xFF, 0x63, 0xFF, 0x33, 0xFF, 0x00, 0x00,
		0x38, 0x00, 0x71, 0xFF, 0x15, 0xFF, 0x00, 0x00, 0xC8, 0xFF, 0x71, 0xFF, 0x15, 0xFF, 0x00, 0x00,
		0xCE, 0x00, 0x03, 0x00, 0x61, 0x00, 0x00, 0x00, 0x38, 0x00, 0xCD, 0xFF, 0x4F, 0xFE, 0x00, 0x00,
		0xC8, 0xFF, 0xCD, 0xFF, 0x4F, 0xFE, 0x00, 0x00, 0xC8, 0xFF, 0xAF, 0xFF, 0x98, 0xFE, 0x00, 0x00,
		0x38, 0x00, 0xAF, 0xFF, 0x98, 0xFE, 0x00, 0x00, 0x38, 0x00, 0xE4, 0xFF, 0x30, 0xFE, 0x00, 0x00,
		0xC8, 0xFF, 0xE4, 0xFF, 0x30, 0xFE, 0x00, 0x00, 0x38, 0x00, 0x04, 0x00, 0x16, 0xFE, 0x00, 0x00,
		0xC8, 0xFF, 0x04, 0x00, 0x16, 0xFE, 0x00, 0x00, 0x38, 0x00, 0x30, 0x00, 0x0C, 0xFE, 0x00, 0x00,
		0xC8, 0xFF, 0x30, 0x00, 0x0C, 0xFE, 0x00, 0x00, 0x6F, 0xFF, 0x2B, 0x00, 0xDE, 0x01, 0x00, 0x00,
		0x87, 0x00, 0x71, 0xFF, 0x46, 0xFF, 0x00, 0x00, 0x87, 0x00, 0x71, 0xFF, 0x3E, 0xFF, 0x00, 0x00,
		0x74, 0x00, 0x68, 0xFF, 0x33, 0xFF, 0x00, 0x00, 0x74, 0x00, 0x68, 0xFF, 0xD6, 0xFF, 0x00, 0x00,
		0x5F, 0xFF, 0xF2, 0xFF, 0xAB, 0x01, 0x00, 0x00, 0x69, 0xFF, 0x0A, 0x00, 0xC9, 0x01, 0x00, 0x00,
		0x54, 0xFF, 0xDB, 0xFF, 0x5D, 0x01, 0x00, 0x00, 0x54, 0xFF, 0xBE, 0xFF, 0x71, 0x00, 0x00, 0x00,
		0xBF, 0x00, 0x0C, 0x00, 0xAC, 0x01, 0x00, 0x00, 0xBF, 0x00, 0xFE, 0xFF, 0x93, 0x01, 0x00, 0x00,
		0xA1, 0x00, 0xF2, 0xFF, 0xAB, 0x01, 0x00, 0x00, 0x8C, 0xFF, 0x68, 0xFF, 0xD6, 0xFF, 0x00, 0x00,
		0x85, 0xFF, 0x71, 0xFF, 0xF8, 0xFF, 0x00, 0x00, 0x8C, 0xFF, 0x68, 0xFF, 0x33, 0xFF, 0x00, 0x00,
		0x85, 0xFF, 0x71, 0xFF, 0x15, 0xFF, 0x00, 0x00, 0xCE, 0x00, 0x50, 0x00, 0xBF, 0x00, 0x00, 0x00,
		0xCE, 0x00, 0x4F, 0x00, 0x62, 0x00, 0x00, 0x00, 0x7A, 0xFF, 0xCD, 0xFF, 0x4F, 0xFE, 0x00, 0x00,
		0x7A, 0xFF, 0xAF, 0xFF, 0xA3, 0xFE, 0x00, 0x00, 0x7A, 0xFF, 0xE4, 0xFF, 0x30, 0xFE, 0x00, 0x00,
		0x7A, 0xFF, 0x04, 0x00, 0x16, 0xFE, 0x00, 0x00, 0xC6, 0x00, 0x26, 0x00, 0xAE, 0x01, 0x00, 0x00,
		0x91, 0x00, 0x2B, 0x00, 0xDE, 0x01, 0x00, 0x00, 0x7A, 0xFF, 0x30, 0x00, 0x0C, 0xFE, 0x00, 0x00,
		0x41, 0xFF, 0x0C, 0x00, 0xAC, 0x01, 0x00, 0x00, 0x41, 0xFF, 0xEC, 0xFF, 0x4C, 0x01, 0x00, 0x00,
		0x41, 0xFF, 0xFE, 0xFF, 0x93, 0x01, 0x00, 0x00, 0x79, 0xFF, 0x71, 0xFF, 0xE0, 0xFF, 0x00, 0x00,
		0x6D, 0xFF, 0x7B, 0xFF, 0xF8, 0xFF, 0x00, 0x00, 0x79, 0xFF, 0x71, 0xFF, 0x2F, 0xFF, 0x00, 0x00,
		0x6B, 0xFF, 0x8E, 0xFF, 0xF6, 0xFE, 0x00, 0x00, 0x62, 0xFF, 0xB9, 0xFF, 0xAE, 0xFE, 0x00, 0x00,
		0x59, 0xFF, 0xD6, 0xFF, 0x61, 0xFE, 0x00, 0x00, 0x54, 0xFF, 0xEE, 0xFF, 0x44, 0xFE, 0x00, 0x00,
		0x54, 0xFF, 0x0A, 0x00, 0x28, 0xFE, 0x00, 0x00, 0xCE, 0x00, 0x02, 0x00, 0xCA, 0xFE, 0x00, 0x00,
		0xBF, 0x00, 0xD0, 0xFF, 0xB8, 0xFE, 0x00, 0x00, 0xBF, 0x00, 0xC4, 0xFF, 0xDC, 0xFE, 0x00, 0x00,
		0x54, 0xFF, 0x30, 0x00, 0x1B, 0xFE, 0x00, 0x00, 0x41, 0xFF, 0xC7, 0xFF, 0x52, 0x00, 0x00, 0x00,
		0x41, 0xFF, 0xC7, 0xFF, 0x6B, 0x00, 0x00, 0x00, 0x41, 0xFF, 0xC4, 0xFF, 0xDC, 0xFE, 0x00, 0x00,
		0x41, 0xFF, 0xC3, 0xFF, 0x02, 0xFF, 0x00, 0x00, 0x41, 0xFF, 0xD0, 0xFF, 0xB8, 0xFE, 0x00, 0x00,
		0x41, 0xFF, 0xE5, 0xFF, 0x80, 0xFE, 0x00, 0x00, 0x41, 0xFF, 0xFC, 0xFF, 0x5F, 0xFE, 0x00, 0x00,
		0x41, 0xFF, 0x15, 0x00, 0x48, 0xFE, 0x00, 0x00, 0x41, 0xFF, 0x39, 0x00, 0x34, 0xFE, 0x00, 0x00,
		0x32, 0xFF, 0x02, 0x00, 0xCA, 0xFE, 0x00, 0x00, 0x32, 0xFF, 0x1B, 0x00, 0x92, 0xFE, 0x00, 0x00,
		0x32, 0xFF, 0x51, 0x00, 0x7E, 0xFE, 0x00, 0x00, 0x32, 0xFF, 0x00, 0x00, 0x42, 0x01, 0x00, 0x00,
		0x32, 0xFF, 0x17, 0x00, 0x7A, 0x01, 0x00, 0x00, 0x3A, 0xFF, 0x26, 0x00, 0xAE, 0x01, 0x00, 0x00,
		0x32, 0xFF, 0x4B, 0x00, 0x91, 0x01, 0x00, 0x00, 0x32, 0xFF, 0x4F, 0x00, 0x19, 0xFF, 0x00, 0x00,
		0x32, 0xFF, 0x4F, 0x00, 0x20, 0xFF, 0x00, 0x00, 0x32, 0xFF, 0x50, 0x00, 0xBF, 0x00, 0x00, 0x00,
		0x32, 0xFF, 0x50, 0x00, 0xF7, 0x00, 0x00, 0x00, 0x32, 0xFF, 0x19, 0x00, 0x0C, 0x01, 0x00, 0x00,
		0x32, 0xFF, 0x19, 0x00, 0x03, 0xFF, 0x00, 0x00, 0x32, 0xFF, 0x03, 0x00, 0xFB, 0xFE, 0x00, 0x00,
		0x32, 0xFF, 0x02, 0x00, 0x0E, 0xFF, 0x00, 0x00, 0x32, 0xFF, 0x03, 0x00, 0x7A, 0x00, 0x00, 0x00,
		0x32, 0xFF, 0x01, 0x00, 0xDC, 0x00, 0x00, 0x00, 0x32, 0xFF, 0x03, 0x00, 0x61, 0x00, 0x00, 0x00,
		0x32, 0xFF, 0x4F, 0x00, 0x62, 0x00, 0x00, 0x00, 0x79, 0xFF, 0x71, 0xFF, 0x3E, 0xFF, 0x00, 0x00,
		0x41, 0xFF, 0xC8, 0xFF, 0x37, 0xFF, 0x00, 0x00, 0x32, 0xFF, 0x02, 0x00, 0x29, 0xFF, 0x00, 0x00,
		0x32, 0xFF, 0x4F, 0x00, 0x34, 0xFF, 0x00, 0x00, 0xCE, 0x00, 0x02, 0x00, 0x29, 0xFF, 0x00, 0x00,
		0xCE, 0x00, 0x02, 0x00, 0x0E, 0xFF, 0x00, 0x00, 0xBF, 0x00, 0xC3, 0xFF, 0x02, 0xFF, 0x00, 0x00,
		0xBF, 0x00, 0xC8, 0xFF, 0x37, 0xFF, 0x00, 0x00, 0xCE, 0x00, 0x4F, 0x00, 0x34, 0xFF, 0x00, 0x00,
		0xCE, 0x00, 0x4F, 0x00, 0x20, 0xFF, 0x00, 0x00, 0x41, 0xFF, 0xC8, 0xFF, 0x45, 0xFF, 0x00, 0x00,
		0xBF, 0x00, 0xC8, 0xFF, 0x45, 0xFF, 0x00, 0x00, 0x79, 0xFF, 0x71, 0xFF, 0x46, 0xFF, 0x00, 0x00,
		0x87, 0x00, 0x71, 0xFF, 0x2F, 0xFF, 0x00, 0x00, 0x97, 0x00, 0x0A, 0x00, 0xC9, 0x01, 0x00, 0x00,
		0xAC, 0x00, 0xDB, 0xFF, 0x5D, 0x01, 0x00, 0x00, 0xAC, 0x00, 0xBE, 0xFF, 0x71, 0x00, 0x00, 0x00,
		0xCE, 0x00, 0x00, 0x00, 0x42, 0x01, 0x00, 0x00, 0xCE, 0x00, 0x19, 0x00, 0x0C, 0x01, 0x00, 0x00,
		0xCE, 0x00, 0x01, 0x00, 0xDC, 0x00, 0x00, 0x00, 0x7B, 0x00, 0x71, 0xFF, 0xF8, 0xFF, 0x00, 0x00,
		0x7B, 0x00, 0x71, 0xFF, 0x15, 0xFF, 0x00, 0x00, 0x86, 0x00, 0xAF, 0xFF, 0xA3, 0xFE, 0x00, 0x00,
		0x86, 0x00, 0xCD, 0xFF, 0x4F, 0xFE, 0x00, 0x00, 0x86, 0x00, 0xE4, 0xFF, 0x30, 0xFE, 0x00, 0x00,
		0x86, 0x00, 0x04, 0x00, 0x16, 0xFE, 0x00, 0x00, 0x86, 0x00, 0x30, 0x00, 0x0C, 0xFE, 0x00, 0x00,
		0xBF, 0x00, 0xEC, 0xFF, 0x4C, 0x01, 0x00, 0x00, 0x93, 0x00, 0x7B, 0xFF, 0xF8, 0xFF, 0x00, 0x00,
		0x87, 0x00, 0x71, 0xFF, 0xE0, 0xFF, 0x00, 0x00, 0x9E, 0x00, 0xB9, 0xFF, 0xAE, 0xFE, 0x00, 0x00,
		0x95, 0x00, 0x8E, 0xFF, 0xF6, 0xFE, 0x00, 0x00, 0xA7, 0x00, 0xD6, 0xFF, 0x61, 0xFE, 0x00, 0x00,
		0xAC, 0x00, 0xEE, 0xFF, 0x44, 0xFE, 0x00, 0x00, 0xAC, 0x00, 0x0A, 0x00, 0x28, 0xFE, 0x00, 0x00,
		0xAC, 0x00, 0x30, 0x00, 0x1B, 0xFE, 0x00, 0x00, 0xBF, 0x00, 0xE5, 0xFF, 0x80, 0xFE, 0x00, 0x00,
		0xBF, 0x00, 0xFC, 0xFF, 0x5F, 0xFE, 0x00, 0x00, 0xBF, 0x00, 0x15, 0x00, 0x48, 0xFE, 0x00, 0x00,
		0xBF, 0x00, 0x39, 0x00, 0x34, 0xFE, 0x00, 0x00, 0xCE, 0x00, 0x1B, 0x00, 0x92, 0xFE, 0x00, 0x00,
		0xCE, 0x00, 0x51, 0x00, 0x7E, 0xFE, 0x00, 0x00, 0xCE, 0x00, 0x17, 0x00, 0x7A, 0x01, 0x00, 0x00,
		0xCE, 0x00, 0x4B, 0x00, 0x91, 0x01, 0x00, 0x00, 0xCE, 0x00, 0x4F, 0x00, 0x19, 0xFF, 0x00, 0x00,
		0xCE, 0x00, 0x50, 0x00, 0xF7, 0x00, 0x00, 0x00, 0xCE, 0x00, 0x19, 0x00, 0x03, 0xFF, 0x00, 0x00,
		0xCE, 0x00, 0x03, 0x00, 0xFB, 0xFE, 0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0xE1, 0xF9, 0xC8, 0x0E, 0x00, 0x00, 0x00, 0x00, 0x38, 0xF1, 0x1F, 0x06, 0x00, 0x00,
		0x00, 0x00, 0x38, 0xF1, 0xE1, 0xF9, 0x00, 0x00, 0x00, 0x00, 0xE1, 0xF9, 0x38, 0xF1, 0x00, 0x00,
		0x00, 0x00, 0x1F, 0x06, 0x38, 0xF1, 0x00, 0x00, 0x00, 0x00, 0xC8, 0x0E, 0xE1, 0xF9, 0x00, 0x00,
		0x00, 0x00, 0xC8, 0x0E, 0x1F, 0x06, 0x00, 0x00, 0x00, 0x00, 0x1F, 0x06, 0xC8, 0x0E, 0x00, 0x00,
		0x00, 0x00, 0xE1, 0xF9, 0xC8, 0x0E, 0x00, 0x00, 0x00, 0x00, 0x38, 0xF1, 0x1F, 0x06, 0x00, 0x00,
		0x00, 0x00, 0x38, 0xF1, 0xE1, 0xF9, 0x00, 0x00, 0x00, 0x00, 0xE1, 0xF9, 0x38, 0xF1, 0x00, 0x00,
		0x00, 0x00, 0x1F, 0x06, 0x38, 0xF1, 0x00, 0x00, 0x00, 0x00, 0xC8, 0x0E, 0xE1, 0xF9, 0x00, 0x00,
		0x00, 0x00, 0xC8, 0x0E, 0x1F, 0x06, 0x00, 0x00, 0x00, 0x00, 0x1F, 0x06, 0xC8, 0x0E, 0x00, 0x00,
		0x00, 0xF0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xE1, 0xF9, 0x38, 0xF1, 0x00, 0x00,
		0x00, 0x00, 0x38, 0xF1, 0xE1, 0xF9, 0x00, 0x00, 0x00, 0x00, 0xE1, 0xF9, 0xC8, 0x0E, 0x00, 0x00,
		0x00, 0x00, 0x1F, 0x06, 0xC8, 0x0E, 0x00, 0x00, 0x00, 0x00, 0x1F, 0x06, 0x38, 0xF1, 0x00, 0x00,
		0x00, 0x00, 0xE1, 0xF9, 0x38, 0xF1, 0x00, 0x00, 0x00, 0x00, 0x38, 0xF1, 0xE1, 0xF9, 0x00, 0x00,
		0x00, 0x00, 0x38, 0xF1, 0x1F, 0x06, 0x00, 0x00, 0x00, 0x00, 0xE1, 0xF9, 0xC8, 0x0E, 0x00, 0x00,
		0x00, 0x00, 0x1F, 0x06, 0xC8, 0x0E, 0x00, 0x00, 0x00, 0x00, 0xC8, 0x0E, 0x1F, 0x06, 0x00, 0x00,
		0x00, 0x00, 0x1F, 0x06, 0x38, 0xF1, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0E, 0xFF, 0xF9, 0x0F, 0x00, 0x00,
		0x00, 0x00, 0x80, 0xF6, 0xE0, 0x0C, 0x00, 0x00, 0x00, 0x00, 0x24, 0xF3, 0x85, 0x09, 0x00, 0x00,
		0x00, 0x00, 0x37, 0xF1, 0x1D, 0x06, 0x00, 0x00, 0x00, 0x00, 0x19, 0xF0, 0xC4, 0x01, 0x00, 0x00,
		0x8B, 0x0F, 0x35, 0xFC, 0x20, 0x00, 0x00, 0x00, 0x00, 0x00, 0x81, 0xF1, 0xC6, 0x06, 0x00, 0x00,
		0x00, 0x00, 0x00, 0xF0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x99, 0xF1, 0x08, 0xF9, 0x00, 0x00,
		0x8F, 0x0F, 0x46, 0xFC, 0x06, 0x00, 0x00, 0x00, 0x00, 0x00, 0x29, 0xF1, 0x04, 0xFA, 0x00, 0x00,
		0x00, 0x00, 0x17, 0xF3, 0x8C, 0xF6, 0x00, 0x00, 0x00, 0x00, 0x34, 0xF6, 0x5A, 0xF3, 0x00, 0x00,
		0x00, 0x00, 0x59, 0xFC, 0x6C, 0xF0, 0x00, 0x00, 0x00, 0x00, 0x77, 0x02, 0x31, 0xF0, 0x00, 0x00,
		0xBA, 0xFC, 0x2E, 0xFF, 0xA4, 0x0F, 0x00, 0x00, 0x63, 0x07, 0xCF, 0xF1, 0x00, 0x00, 0x00, 0x00,
		0x53, 0xFF, 0x48, 0xF3, 0xAF, 0x09, 0x00, 0x00, 0x6E, 0xFF, 0xF6, 0xF0, 0x6E, 0x05, 0x00, 0x00,
		0x94, 0xFF, 0x1D, 0xF0, 0xDE, 0x01, 0x00, 0x00, 0x46, 0x09, 0xB0, 0xF4, 0x7A, 0x06, 0x00, 0x00,
		0xD1, 0xFE, 0xFB, 0xF0, 0x64, 0x05, 0x00, 0x00, 0xBC, 0xFE, 0x0D, 0xF0, 0x00, 0x00, 0x00, 0x00,
		0x6E, 0xFF, 0x29, 0xF1, 0x0D, 0xFA, 0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x97, 0xFF, 0x09, 0xF1, 0x5A, 0xFA, 0x00, 0x00, 0x00, 0x00, 0x34, 0xF6, 0x5A, 0xF3, 0x00, 0x00,
		0xB3, 0x0A, 0xA5, 0xFF, 0xE4, 0x0B, 0x00, 0x00, 0x00, 0x00, 0x77, 0x02, 0x31, 0xF0, 0x00, 0x00,
		0x46, 0xF8, 0x5D, 0xF6, 0x2C, 0x0A, 0x00, 0x00, 0xC1, 0xF5, 0x56, 0xF4, 0xDF, 0x03, 0x00, 0x00,
		0x11, 0xFA, 0x6B, 0xF1, 0xDD, 0x02, 0x00, 0x00, 0x49, 0xF9, 0xD5, 0xF1, 0xD1, 0xFC, 0x00, 0x00,
		0x1D, 0xF8, 0xA3, 0xF3, 0x9A, 0xF9, 0x00, 0x00, 0x2E, 0xF9, 0x48, 0xF2, 0x64, 0xFB, 0x00, 0x00,
		0x76, 0xF8, 0x9A, 0xF4, 0xAF, 0xF7, 0x00, 0x00, 0xC2, 0xF8, 0x91, 0xF6, 0x4D, 0xF5, 0x00, 0x00,
		0x72, 0x0F, 0x02, 0xFC, 0xC8, 0xFE, 0x00, 0x00, 0x53, 0xFB, 0x90, 0x01, 0xC7, 0xF0, 0x00, 0x00,
		0xE8, 0xF0, 0x06, 0xFE, 0x14, 0xFB, 0x00, 0x00, 0x75, 0xF3, 0x22, 0xF6, 0xDB, 0xFE, 0x00, 0x00,
		0xE5, 0xF5, 0x6A, 0xF4, 0x90, 0xFB, 0x00, 0x00, 0x53, 0xF5, 0xB0, 0xF4, 0x40, 0xFC, 0x00, 0x00,
		0x41, 0xF3, 0xDC, 0xF7, 0xC8, 0xFA, 0x00, 0x00, 0x86, 0xF2, 0xFF, 0xF9, 0xCF, 0xF9, 0x00, 0x00,
		0x8D, 0xF2, 0x6B, 0xFC, 0x1B, 0xF8, 0x00, 0x00, 0x8E, 0xF0, 0x1F, 0xFC, 0x78, 0xFE, 0x00, 0x00,
		0x8A, 0xF0, 0x9A, 0xFC, 0xAB, 0xFD, 0x00, 0x00, 0x40, 0xF0, 0x10, 0xFE, 0xF3, 0xFD, 0x00, 0x00,
		0x33, 0xF0, 0xC6, 0xFE, 0xCD, 0xFD, 0x00, 0x00, 0xA6, 0xF2, 0x73, 0xF7, 0x28, 0x02, 0x00, 0x00,
		0x5F, 0xF1, 0x00, 0xFA, 0x71, 0x02, 0x00, 0x00, 0xF4, 0xF0, 0xCA, 0xFB, 0x72, 0x03, 0x00, 0x00,
		0x43, 0xF1, 0x98, 0xFA, 0x18, 0x03, 0x00, 0x00, 0x38, 0xF9, 0xC3, 0xF2, 0xE6, 0x05, 0x00, 0x00,
		0x62, 0xF6, 0x56, 0xF3, 0xC8, 0x01, 0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x2A, 0xF5, 0x77, 0xFF, 0xC3, 0x0B, 0x00, 0x00, 0xFF, 0xF2, 0xF2, 0x00, 0xB9, 0xF6, 0x00, 0x00,
		0x27, 0xF7, 0x59, 0xF3, 0xCE, 0xFB, 0x00, 0x00, 0x44, 0xF0, 0xDB, 0xFE, 0xA8, 0x02, 0x00, 0x00,
		0xA2, 0xF0, 0x27, 0x00, 0x75, 0x04, 0x00, 0x00, 0x6B, 0xF0, 0x5D, 0xFC, 0x12, 0x00, 0x00, 0x00,
		0x65, 0xF0, 0x79, 0xFC, 0xD4, 0xFF, 0x00, 0x00, 0x00, 0xF0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x72, 0xF0, 0x42, 0xFC, 0xEB, 0xFF, 0x00, 0x00, 0x00, 0xF0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x81, 0xF0, 0x5C, 0xFC, 0x5E, 0xFE, 0x00, 0x00, 0x77, 0xF0, 0xA5, 0xFE, 0x6D, 0xFC, 0x00, 0x00,
		0x63, 0xF0, 0x8D, 0x00, 0x8B, 0xFC, 0x00, 0x00, 0x88, 0xF0, 0xEF, 0xFF, 0xEA, 0xFB, 0x00, 0x00,
		0x75, 0xF0, 0x35, 0xFC, 0x20, 0x00, 0x00, 0x00, 0xBA, 0xF6, 0xB0, 0xF4, 0x7A, 0x06, 0x00, 0x00,
		0x77, 0xF0, 0x2D, 0xFC, 0xF7, 0xFF, 0x00, 0x00, 0xBD, 0xF2, 0x2A, 0xF7, 0x6D, 0x01, 0x00, 0x00,
		0x4D, 0xF5, 0xA5, 0xFF, 0xE4, 0x0B, 0x00, 0x00, 0x8E, 0xF0, 0x02, 0xFC, 0xC8, 0xFE, 0x00, 0x00,
		0x71, 0xF0, 0x46, 0xFC, 0x06, 0x00, 0x00, 0x00, 0x00, 0xF0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0xF0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x9D, 0xF8, 0xCF, 0xF1, 0x00, 0x00, 0x00, 0x00,
		0xA0, 0xF2, 0x3A, 0xF7, 0x6C, 0x00, 0x00, 0x00, 0x6D, 0xF0, 0x55, 0xFC, 0x31, 0x00, 0x00, 0x00,
		0x00, 0xF0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x8F, 0x0F, 0x44, 0xFC, 0x2F, 0x00, 0x00, 0x00,
		0x00, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x79, 0xF0, 0x26, 0xFC, 0xFA, 0xFF, 0x00, 0x00,
		0x87, 0x0F, 0x26, 0xFC, 0xFA, 0xFF, 0x00, 0x00, 0x9B, 0xF2, 0x3F, 0xF7, 0xF9, 0xFF, 0x00, 0x00,
		0x9D, 0xF8, 0xCF, 0xF1, 0x00, 0x00, 0x00, 0x00, 0x9D, 0xF8, 0xCF, 0xF1, 0x00, 0x00, 0x00, 0x00,
		0x63, 0x07, 0xCF, 0xF1, 0x00, 0x00, 0x00, 0x00, 0x44, 0x03, 0x2E, 0xFF, 0xA4, 0x0F, 0x00, 0x00,
		0x65, 0x0D, 0x3F, 0xF7, 0xF9, 0xFF, 0x00, 0x00, 0xB8, 0x00, 0x58, 0xF3, 0xC4, 0x09, 0x00, 0x00,
		0x96, 0x00, 0xEF, 0xF0, 0x5C, 0x05, 0x00, 0x00, 0x6D, 0x00, 0x1D, 0xF0, 0xDE, 0x01, 0x00, 0x00,
		0x40, 0x01, 0x07, 0xF1, 0x7F, 0x05, 0x00, 0x00, 0x44, 0x01, 0x0D, 0xF0, 0x00, 0x00, 0x00, 0x00,
		0x9B, 0x00, 0x1E, 0xF1, 0x29, 0xFA, 0x00, 0x00, 0x49, 0x0D, 0x18, 0xF7, 0x6B, 0x00, 0x00, 0x00,
		0x5D, 0x00, 0x09, 0xF1, 0x5A, 0xFA, 0x00, 0x00, 0x89, 0x0F, 0x2D, 0xFC, 0xF7, 0xFF, 0x00, 0x00,
		0x00, 0x00, 0x77, 0x02, 0x31, 0xF0, 0x00, 0x00, 0xBA, 0x07, 0x5D, 0xF6, 0x2C, 0x0A, 0x00, 0x00,
		0x33, 0x0A, 0x5D, 0xF4, 0x10, 0x04, 0x00, 0x00, 0xDC, 0x05, 0x68, 0xF1, 0xF1, 0x02, 0x00, 0x00,
		0xB7, 0x06, 0xD5, 0xF1, 0xD1, 0xFC, 0x00, 0x00, 0xE3, 0x07, 0xA3, 0xF3, 0x9A, 0xF9, 0x00, 0x00,
		0xD4, 0x06, 0x42, 0xF2, 0x77, 0xFB, 0x00, 0x00, 0x8A, 0x07, 0x99, 0xF4, 0xAF, 0xF7, 0x00, 0x00,
		0x4B, 0x07, 0x9E, 0xF6, 0x4A, 0xF5, 0x00, 0x00, 0x43, 0x0D, 0x2A, 0xF7, 0x6D, 0x01, 0x00, 0x00,
		0xB0, 0x04, 0x99, 0x01, 0xC9, 0xF0, 0x00, 0x00, 0xF6, 0x0E, 0xDF, 0xFB, 0x1E, 0xFC, 0x00, 0x00,
		0x83, 0x0C, 0x1F, 0xF6, 0x9D, 0xFE, 0x00, 0x00, 0x95, 0x0A, 0xDF, 0xF4, 0x81, 0xFB, 0x00, 0x00,
		0x4F, 0x0A, 0x5E, 0xF4, 0x36, 0xFC, 0x00, 0x00, 0xBA, 0x0C, 0xCF, 0xF7, 0xD0, 0xFA, 0x00, 0x00,
		0x78, 0x0D, 0xFD, 0xF9, 0xCC, 0xF9, 0x00, 0x00, 0x6F, 0x0D, 0x89, 0xFC, 0x08, 0xF8, 0x00, 0x00,
		0x72, 0x0F, 0x1F, 0xFC, 0x78, 0xFE, 0x00, 0x00, 0x76, 0x0F, 0x9A, 0xFC, 0xAB, 0xFD, 0x00, 0x00,
		0xC0, 0x0F, 0x10, 0xFE, 0xF3, 0xFD, 0x00, 0x00, 0xCD, 0x0F, 0xC6, 0xFE, 0xCD, 0xFD, 0x00, 0x00,
		0x5A, 0x0D, 0x73, 0xF7, 0x28, 0x02, 0x00, 0x00, 0xA1, 0x0E, 0x00, 0xFA, 0x71, 0x02, 0x00, 0x00,
		0x0C, 0x0F, 0xCA, 0xFB, 0x72, 0x03, 0x00, 0x00, 0xBD, 0x0E, 0x98, 0xFA, 0x18, 0x03, 0x00, 0x00,
		0xD4, 0x06, 0xC9, 0xF2, 0xE4, 0x05, 0x00, 0x00, 0x92, 0x09, 0x4F, 0xF3, 0xD5, 0x01, 0x00, 0x00,
		0xD6, 0x0A, 0x77, 0xFF, 0xC3, 0x0B, 0x00, 0x00, 0xE8, 0x0C, 0x08, 0x01, 0x9A, 0xF6, 0x00, 0x00,
		0xD9, 0x08, 0x59, 0xF3, 0xCE, 0xFB, 0x00, 0x00, 0xBC, 0x0F, 0xDB, 0xFE, 0xA8, 0x02, 0x00, 0x00,
		0x4B, 0x0F, 0x2A, 0x00, 0xB2, 0x04, 0x00, 0x00, 0x95, 0x0F, 0x5D, 0xFC, 0x12, 0x00, 0x00, 0x00,
		0x9B, 0x0F, 0x7A, 0xFC, 0xD4, 0xFF, 0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x8E, 0x0F, 0x42, 0xFC, 0xEB, 0xFF, 0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x7F, 0x0F, 0x5C, 0xFC, 0x5E, 0xFE, 0x00, 0x00, 0x89, 0x0F, 0xA5, 0xFE, 0x6D, 0xFC, 0x00, 0x00,
		0x9D, 0x0F, 0x8D, 0x00, 0x8B, 0xFC, 0x00, 0x00, 0x78, 0x0F, 0xEF, 0xFF, 0xEA, 0xFB, 0x00, 0x00,
		0x00, 0x00, 0x41, 0xF2, 0x30, 0x08, 0x00, 0x00, 0x32, 0xFF, 0x54, 0xF2, 0x46, 0x08, 0x00, 0x00,
		0xCD, 0x00, 0x4D, 0xF2, 0x3B, 0x08, 0x00, 0x00, 0x00, 0x00, 0x59, 0xFC, 0x6C, 0xF0, 0x00, 0x00,
		0xB3, 0xF9, 0xF2, 0xFB, 0xDD, 0xF1, 0x00, 0x00, 0x00, 0x00, 0x59, 0xFC, 0x6C, 0xF0, 0x00, 0x00,
		0x61, 0x06, 0xFB, 0xFB, 0xE3, 0xF1, 0x00, 0x00, 0xED, 0x01, 0x5F, 0xF7, 0x56, 0x0D, 0x00, 0x00,
		0x8E, 0x09, 0x20, 0xFB, 0xDF, 0x0B, 0x00, 0x00, 0x17, 0xFE, 0x65, 0xF7, 0x5A, 0x0D, 0x00, 0x00,
		0x81, 0xF6, 0x73, 0xFB, 0x0C, 0x0C, 0x00, 0x00, 0x00, 0x00, 0xAD, 0xF1, 0xDF, 0xF8, 0x00, 0x00,
		0x7C, 0xFF, 0xCB, 0xF1, 0xA8, 0xF8, 0x00, 0x00, 0x94, 0x06, 0xEC, 0xF2, 0x8B, 0xF9, 0x00, 0x00,
		0x6C, 0xF9, 0xEC, 0xF2, 0x8B, 0xF9, 0x00, 0x00, 0x7C, 0x00, 0xD0, 0xF1, 0x9E, 0xF8, 0x00, 0x00,
		0x61, 0x0D, 0x39, 0xF7, 0xFC, 0xFF, 0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x8C, 0x0F, 0x37, 0xFC, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0xF0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x74, 0xF0, 0x39, 0xFC, 0x00, 0x00, 0x00, 0x00, 0xA2, 0xF2, 0x35, 0xF7, 0xFC, 0xFF, 0x00, 0x00
};



const unsigned char COM_TIM[1088] = {
		0x10, 0x00, 0x00, 0x00, 0x08, 0x00, 0x00, 0x00, 0x2C, 0x00, 0x00, 0x00, 0x80, 0x01, 0x20, 0x00,
		0x10, 0x00, 0x01, 0x00, 0x00, 0x80, 0x10, 0x00, 0x00, 0x02, 0x10, 0x02, 0x00, 0x40, 0x10, 0x40,
		0x00, 0x42, 0x18, 0x63, 0x10, 0x42, 0x1F, 0x00, 0xE0, 0x03, 0xFF, 0x03, 0x00, 0x7C, 0x1F, 0x7C,
		0xE0, 0x7F, 0xFF, 0x7F, 0x0C, 0x04, 0x00, 0x00, 0x80, 0x01, 0x00, 0x00, 0x10, 0x00, 0x20, 0x00,
		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
		0xFF, 0xFF, 0xFF, 0xFF, 0xCC, 0xCC, 0xCC, 0xCC, 0xFF, 0xFF, 0xFF, 0xCF, 0xCC, 0xCC, 0xFF, 0xFF,
		0xFF, 0xFF, 0xCC, 0xFC, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
		0xFF, 0xFF, 0xFF, 0xFF, 0xCC, 0xCC, 0xCC, 0xCC, 0xFF, 0xFF, 0xFF, 0xCF, 0xCC, 0xCC, 0xCC, 0xFC,
		0xFF, 0xFF, 0xCC, 0xFC, 0xCF, 0xCC, 0xFC, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
		0xFF, 0xFF, 0xFF, 0xFF, 0xCC, 0xCC, 0xCC, 0xCC, 0xFF, 0xFF, 0xFF, 0xCC, 0xCC, 0xCC, 0xCC, 0xFC,
		0xFF, 0xFF, 0xCC, 0xFC, 0xCC, 0xCC, 0xFC, 0xCC, 0xCC, 0xCC, 0xFC, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
		0xFF, 0xFF, 0xFF, 0xCF, 0xCC, 0xFC, 0xFF, 0xFF, 0xFF, 0xFF, 0xCF, 0xCC, 0xCC, 0xCC, 0xCC, 0xFC,
		0xFF, 0xFF, 0xCC, 0xCC, 0xCC, 0xCC, 0xCC, 0xCC, 0xCC, 0xCC, 0xFC, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
		0xFF, 0xFF, 0xFF, 0xCF, 0xCC, 0xFC, 0xFF, 0xFF, 0xFF, 0xFF, 0xCF, 0xCC, 0xFC, 0xCF, 0xCC, 0xFC,
		0xFF, 0xFF, 0xCC, 0xCC, 0xCC, 0xCC, 0xCC, 0xCC, 0xCC, 0xCC, 0xFC, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
		0xFF, 0xFF, 0xFF, 0xCF, 0xCC, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xCF, 0xCC, 0xFF, 0xCF, 0xCC, 0xFF,
		0xFF, 0xFF, 0xCC, 0xCC, 0xCC, 0xCC, 0xCC, 0xCC, 0xFF, 0xCC, 0xFC, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
		0xFF, 0xFF, 0xFF, 0xCF, 0xCC, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xCF, 0xCC, 0xFF, 0xCF, 0xCC, 0xFF,
		0xFF, 0xFF, 0xCC, 0xCC, 0xFF, 0xCC, 0xCC, 0xFC, 0xFF, 0xCC, 0xFC, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
		0xFF, 0xFF, 0xFF, 0xCF, 0xCC, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xCF, 0xCC, 0xFF, 0xCF, 0xCC, 0xFF,
		0xFF, 0xFF, 0xCC, 0xFC, 0xFF, 0xCC, 0xCC, 0xFF, 0xFF, 0xCC, 0xFC, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
		0xFF, 0xFF, 0xFF, 0xCF, 0xCC, 0xCC, 0xCC, 0xFC, 0xFF, 0xFF, 0xCF, 0xCC, 0xFF, 0xCF, 0xCC, 0xFF,
		0xFF, 0xFF, 0xCC, 0xFC, 0xFF, 0xCC, 0xCC, 0xFF, 0xFF, 0xCC, 0xFC, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
		0xFF, 0xFF, 0xFF, 0xCF, 0xCC, 0xCC, 0xCC, 0xFC, 0xFF, 0xFF, 0xCF, 0xCC, 0xCC, 0xCC, 0xCC, 0xFF,
		0xFF, 0xFF, 0xCC, 0xFC, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xCC, 0xFC, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
		0xFF, 0xFF, 0xFF, 0xFF, 0xCC, 0xCC, 0xCC, 0xFC, 0xFF, 0xFF, 0xCF, 0xCC, 0xCC, 0xCC, 0xCC, 0xFF,
		0xFF, 0xFF, 0xCC, 0xFC, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xCC, 0xFC, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xCF, 0xCC, 0xCC, 0xCC, 0xCC, 0xFF,
		0xFF, 0xFF, 0xCC, 0xFC, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xCC, 0xFC, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
		0xFF, 0xFF, 0xCC, 0xFC, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xCC, 0xFC, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
		0xFF, 0xFF, 0xCC, 0xFC, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xCC, 0xFC, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xCC, 0xCC, 0xFC, 0xFF, 0xCF, 0xCC, 0xCC, 0xFF,
		0xFF, 0xFF, 0xCC, 0xFC, 0xFF, 0xFF, 0xFF, 0xCC, 0xFC, 0xCC, 0xFC, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xCF, 0xCC, 0xCC, 0xCC, 0xFF, 0xCF, 0xCC, 0xCC, 0xFC,
		0xFF, 0xCF, 0xCC, 0xFC, 0xFF, 0xFF, 0xCC, 0xCC, 0xFC, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xCF, 0xFF, 0xCF, 0xCC, 0xFF, 0xCC, 0xFF, 0xCF, 0xFC,
		0xFF, 0xFF, 0xCC, 0xFC, 0xFF, 0xFF, 0xFF, 0xCC, 0xFC, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xCF, 0xCC, 0xFF, 0xFF, 0xFF, 0xCF, 0xFC,
		0xFF, 0xFF, 0xCC, 0xFC, 0xFF, 0xFF, 0xFF, 0xCC, 0xFC, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xCF, 0xFC, 0xFF, 0xFF, 0xFF, 0xCF, 0xFC,
		0xFF, 0xFF, 0xCC, 0xFC, 0xFF, 0xFF, 0xFF, 0xCC, 0xFC, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xCC, 0xFC, 0xFF, 0xFF, 0xFF, 0xCC, 0xFF,
		0xFF, 0xFF, 0xCF, 0xFC, 0xFF, 0xFF, 0xFF, 0xCC, 0xFC, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xCC, 0xCC, 0xCC, 0xFF, 0xFF, 0xCC, 0xCC, 0xFC,
		0xFF, 0xFF, 0xCF, 0xFC, 0xFF, 0xFF, 0xFF, 0xCC, 0xFC, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xCC, 0xCC, 0xFF, 0xFF, 0xFF, 0xCC, 0xCC,
		0xFF, 0xFF, 0xCF, 0xFC, 0xFF, 0xFF, 0xFF, 0xCC, 0xFC, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xCF, 0xCC, 0xFF, 0xFF, 0xFF, 0xCF, 0xCC,
		0xFF, 0xFF, 0xCF, 0xFC, 0xFF, 0xFF, 0xFF, 0xCC, 0xFC, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xCC, 0xFF, 0xFF, 0xFF, 0xCF, 0xCC,
		0xFF, 0xFF, 0xCF, 0xFC, 0xFF, 0xFF, 0xFF, 0xCC, 0xFC, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xCC, 0xFF, 0xFF, 0xFF, 0xCF, 0xFC,
		0xFF, 0xFF, 0xCF, 0xFC, 0xFF, 0xFF, 0xFF, 0xCC, 0xFC, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xCC, 0xFC, 0xCF, 0xFC, 0xFF, 0xCC, 0xFF, 0xCF, 0xFC,
		0xFF, 0xFF, 0xCF, 0xFC, 0xFF, 0xFF, 0xFF, 0xCC, 0xFC, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xCC, 0xCC, 0xCC, 0xFC, 0xFF, 0xCC, 0xCC, 0xCC, 0xFF,
		0xFF, 0xCF, 0xCC, 0xCC, 0xFC, 0xFF, 0xCF, 0xCC, 0xCC, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xCF, 0xCC, 0xFC, 0xFF, 0xFF, 0xCF, 0xCC, 0xFF, 0xFF,
		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF
};
